@@ -11,9 +11,11 @@ import warnings
 from collections import defaultdict, OrderedDict
 from datetime import datetime
 from enum import Enum
-from functools import reduce
+from functools import partial, reduce
 from typing import Any, Dict, Iterable, List, Mapping, Optional, Set, Tuple, Type
 
+import ax.core.observation as observation
+
 import pandas as pd
 from ax.core.arm import Arm
 from ax.core.base_trial import BaseTrial, DEFAULT_STATUSES_TO_WARM_START, TrialStatus
@@ -26,13 +28,14 @@ from ax.core.metric import Metric, MetricFetchE, MetricFetchResult
 from ax.core.optimization_config import OptimizationConfig
 from ax.core.parameter import Parameter
 from ax.core.runner import Runner
-from ax.core.search_space import SearchSpace
+from ax.core.search_space import HierarchicalSearchSpace, SearchSpace
 from ax.core.trial import Trial
-from ax.exceptions.core import UnsupportedError
+from ax.core.types import TParameterization
+from ax.exceptions.core import UnsupportedError, UserInputError
 from ax.utils.common.base import Base
 from ax.utils.common.constants import EXPERIMENT_IS_TEST_WARNING, Keys
 from ax.utils.common.docutils import copy_doc
-from ax.utils.common.logger import get_logger
+from ax.utils.common.logger import _round_floats_for_logging, get_logger
 from ax.utils.common.result import Err, Ok
 from ax.utils.common.timeutils import current_timestamp_in_millis
 from ax.utils.common.typeutils import checked_cast, not_none
@@ -54,6 +57,14 @@ DATA_TYPE_LOOKUP: Dict[DataType, Type] = {
 
 DEFAULT_OBJECTIVE_NAME = "objective"
 
+ROUND_FLOATS_IN_LOGS_TO_DECIMAL_PLACES: int = 6
+
+# pyre-fixme[5]: Global expression must be annotated.
+round_floats_for_logging = partial(
+    _round_floats_for_logging,
+    decimal_places=ROUND_FLOATS_IN_LOGS_TO_DECIMAL_PLACES,
+)
+
 
 # pyre-fixme[13]: Attribute `_search_space` is never initialized.
 class Experiment(Base):
@@ -646,11 +657,17 @@ class Experiment(Base):
             }
 
         if contains_new_data:
-            self.attach_fetch_results(
-                results=results,
-                combine_with_last_data=combine_with_last_data,
-                overwrite_existing_data=overwrite_existing_data,
-            )
+            try:
+                self.attach_fetch_results(
+                    results=results,
+                    combine_with_last_data=combine_with_last_data,
+                    overwrite_existing_data=overwrite_existing_data,
+                )
+            except ValueError as e:
+                logger.error(
+                    f"Encountered ValueError {e} while attaching results. Proceeding "
+                    "and returning Results fetched without attaching."
+                )
 
         return results
 
@@ -766,11 +783,12 @@ class Experiment(Base):
                     _, last_data = list(current_trial_data.items())[-1]
                     last_data_metrics = set(last_data.df["metric_name"])
                     new_data_metrics = set(trial_df["metric_name"])
-                    if last_data_metrics.difference(new_data_metrics):
+                    difference = last_data_metrics.difference(new_data_metrics)
+                    if len(difference) > 0:
                         raise ValueError(
                             "overwrite_trial_data is True, but the new data contains "
                             "only a subset of the metrics that are present in the "
-                            "previous data."
+                            f"previous data. Missing metrics: {difference}"
                         )
                 current_trial_data = OrderedDict(
                     {cur_time_millis: data_type(**data_init_args)}
@@ -1093,6 +1111,7 @@ class Experiment(Base):
         old_experiment: Experiment,
         copy_run_metadata_keys: Optional[List[str]] = None,
         trial_statuses_to_copy: Optional[List[TrialStatus]] = None,
+        search_space_check_membership_raise_error: bool = True,
     ) -> List[Trial]:
         """Copy all completed trials with data from an old Ax expeirment to this one.
         This function checks that the parameters of each trial are members of the
@@ -1108,6 +1127,9 @@ class Experiment(Base):
             trial_statuses_to_copy: All trials with a status in this list will be
                 copied. By default, copies all ``RUNNING``, ``COMPLETED``,
                 ``ABANDONED``, and ``EARLY_STOPPED`` trials.
+            search_space_check_membership_raise_error: Whether to raise an exception
+                if the warm started trials being imported fall outside of the
+                defined search space.
 
         Returns:
             List of trials successfully copied from old_experiment to this one
@@ -1147,7 +1169,8 @@ class Experiment(Base):
                     "Only experiments with 1-arm trials currently supported."
                 )
             self.search_space.check_membership(
-                not_none(trial.arm).parameters, raise_error=True
+                not_none(trial.arm).parameters,
+                raise_error=search_space_check_membership_raise_error,
             )
             dat, ts = old_experiment.lookup_data_for_trial(trial_index=trial.index)
             # Set trial index and arm name to their values in new trial.
@@ -1302,6 +1325,116 @@ class Experiment(Base):
         """
         return trial_type is None
 
+    def attach_trial(
+        self,
+        parameterizations: List[TParameterization],
+        arm_names: Optional[List[str]] = None,
+        ttl_seconds: Optional[int] = None,
+        run_metadata: Optional[Dict[str, Any]] = None,
+        optimize_for_power: bool = False,
+    ) -> Tuple[Dict[str, TParameterization], int]:
+        """Attach a new trial with the given parameterization to the experiment.
+
+        Args:
+            parameterizations: List of parameterization for the new trial. If
+                only one is provided a single-arm Trial is created. If multiple
+                arms are provided a BatchTrial is created.
+            arm_names: Names of arm(s) in the new trial.
+            ttl_seconds: If specified, will consider the trial failed after this
+                many seconds. Used to detect dead trials that were not marked
+                failed properly.
+            run_metadata: Metadata to attach to the trial.
+            optimize_for_power: For BatchTrial only.
+                Whether to optimize the weights of arms in this
+                trial such that the experiment's power to detect effects of
+                certain size is as high as possible. Refer to documentation of
+                `BatchTrial.set_status_quo_and_optimize_power` for more detail.
+
+        Returns:
+            Tuple of arm name to parameterization dict, and trial index from
+            newly created trial.
+        """
+
+        # If more than one parameterization is provided,
+        # proceed with a batch trial
+        is_batch = len(parameterizations) > 1
+
+        # Validate search space membership for all parameterizations
+        for parameterization in parameterizations:
+            self.search_space.validate_membership(parameters=parameterization)
+
+        # Validate number of arm names if any arm names are provided.
+        named_arms = False
+        arm_names = arm_names or []
+        if len(arm_names) > 0:
+            named_arms = True
+            if len(arm_names) != len(parameterizations):
+                raise UserInputError(
+                    f"Number of arm names ({len(arm_names)} "
+                    "does not match number of parameterizations "
+                    f"({len(parameterizations)})."
+                )
+
+        # Prepare arm(s) to be added to the trial created later
+        arms = [
+            Arm(
+                parameters=parameterization,
+                name=arm_names[i] if named_arms else None,
+            )
+            for i, parameterization in enumerate(parameterizations)
+        ]
+
+        # Create the trial and add arm(s)
+        trial = None
+        if is_batch:
+            # TODO: HSS support for batch trials.
+            if self.search_space.is_hierarchical:
+                raise NotImplementedError(
+                    "Support for batch trials "
+                    "in hierarchical search space coming soon. Let "
+                    "the Ax developers know if you have a use "
+                    "case for it."
+                )
+
+            trial = self.new_batch_trial(
+                ttl_seconds=ttl_seconds, optimize_for_power=optimize_for_power
+            ).add_arms_and_weights(arms=arms)
+
+        else:
+            # If search space is hierarchical, we need to store dummy values of
+            # parameters that are not in the arm (but are in flattened
+            # search space), as metadata, so later we are able to make the
+            # data for this arm "complete" in the flattened search space.
+            candidate_metadata = None
+            if self.search_space.is_hierarchical:
+                hss = checked_cast(HierarchicalSearchSpace, self.search_space)
+                candidate_metadata = hss.cast_observation_features(
+                    observation_features=hss.flatten_observation_features(
+                        observation_features=observation.ObservationFeatures(
+                            parameters=parameterizations[0]
+                        ),
+                        inject_dummy_values_to_complete_flat_parameterization=True,
+                    )
+                ).metadata
+
+            trial = self.new_trial(ttl_seconds=ttl_seconds).add_arm(
+                arms[0],
+                candidate_metadata=candidate_metadata,
+            )
+
+        trial.mark_running(no_runner_required=True)
+
+        logger.info(
+            "Attached custom parameterizations "
+            f"{round_floats_for_logging(item=parameterizations)} "
+            f"as trial {trial.index}."
+        )
+
+        if run_metadata is not None:
+            trial.update_run_metadata(metadata=run_metadata)
+
+        return {arm.name: arm.parameters for arm in trial.arms}, trial.index
+
 
 def add_arm_and_prevent_naming_collision(
     new_trial: Trial, old_trial: Trial, old_experiment_name: Optional[str] = None
