@@ -8,6 +8,7 @@ from __future__ import annotations
 
 from abc import ABCMeta, abstractmethod
 from enum import Enum
+from math import inf
 from typing import Dict, List, Optional, Tuple, Type, Union
 from warnings import warn
 
@@ -77,6 +78,10 @@ class Parameter(SortableBase, metaclass=ABCMeta):
     def validate(self, value: TParamValue) -> bool:
         pass  # pragma: no cover
 
+    @abstractmethod
+    def cardinality(self) -> float:
+        pass  # pragma: no cover
+
     @property
     def python_type(self) -> TParameterType:
         """The python type for the corresponding ParameterType enum.
@@ -197,6 +202,12 @@ class RangeParameter(Parameter):
             logit_scale=logit_scale,
         )
 
+    def cardinality(self) -> float:
+        if self.parameter_type == ParameterType.FLOAT:
+            return inf
+
+        return self.upper - self.lower + 1
+
     def _validate_range_param(
         self,
         lower: TParamValue,
@@ -487,6 +498,9 @@ class ChoiceParameter(Parameter):
         )
         return default_bool
 
+    def cardinality(self) -> float:
+        return len(self.values)
+
     @property
     def sort_values(self) -> bool:
         return self._sort_values
@@ -631,6 +645,9 @@ class FixedParameter(Parameter):
                 )
         self._dependents = dependents
 
+    def cardinality(self) -> float:
+        return 1.0
+
     @property
     def value(self) -> TParamValue:
         return self._value
