@@ -364,6 +364,26 @@ class SearchSpace(Base):
                             f"`{parameter_name}` does not exist in search space."
                         )
 
+    def validate_membership(self, parameters: TParameterization) -> None:
+        self.check_membership(parameterization=parameters, raise_error=True)
+        # `check_membership` uses int and float interchangeably, which we don't
+        # want here.
+        for p_name, parameter in self.parameters.items():
+            if isinstance(self, HierarchicalSearchSpace) and p_name not in parameters:
+                # Parameterizations in HSS-s can be missing some of the dependent
+                # parameters based on the hierarchical structure and values of
+                # the parameters those depend on.
+                continue
+            param_val = parameters.get(p_name)
+            if not isinstance(param_val, parameter.python_type):
+                typ = type(param_val)
+                raise UnsupportedError(
+                    f"Value for parameter {p_name}: {param_val} is of type {typ}, "
+                    f"expected  {parameter.python_type}. If the intention was to have"
+                    f" the parameter on experiment be of type {typ}, set `value_type`"
+                    f" on experiment creation for {p_name}."
+                )
+
     def __repr__(self) -> str:
         return (
             f"{self.__class__.__name__}("
@@ -667,6 +687,27 @@ class HierarchicalSearchSpace(SearchSpace):
 
         return self.parameters[root_parameters.pop()]
 
+    @property
+    def height(self) -> int:
+        """
+        Height of the underlying tree structure of this hierarchical search space.
+        """
+
+        def _height_from_parameter(parameter: Parameter) -> int:
+            if len(parameter.dependents) == 0:
+                return 1
+
+            return (
+                max(
+                    _height_from_parameter(parameter=self[param_name])
+                    for deps in parameter.dependents.values()
+                    for param_name in deps
+                )
+                + 1
+            )
+
+        return _height_from_parameter(parameter=self.root)
+
     def _validate_hierarchical_structure(self) -> None:
         """Validate the structure of this hierarchical search space, ensuring that all
         subtrees are independent (not sharing any parameters) and that all parameters
@@ -924,7 +965,9 @@ class SearchSpaceDigest:
     """Container for lightweight representation of search space properties.
 
     This is used for communicating between modelbridge and models. This is
-    an ephemeral object and not meant to be stored / serialized.
+    an ephemeral object and not meant to be stored / serialized. It is typically
+    constructed from the transformed search space using `extract_search_space_digest`,
+    whose docstring explains how various fields are populated.
 
     Attributes:
         feature_names: A list of parameter names.
