@@ -652,3 +652,40 @@ class BatchTrialTest(TestCase):
             generator_run=generator_run, weight=2.0
         )
         self.assertTrue(generator_run_struct < generator_run_struct_2)
+
+    def test_attach_batch_trial_data(self) -> None:
+        # Verify components before we attach trial data
+        self.assertEqual(2, len(self.batch.arms))
+        arm1_name = self.batch.arms[0].name
+        arm2_name = self.batch.arms[1].name
+
+        self.assertEqual(
+            2,
+            len(self.batch.experiment.metrics)
+            - len(self.batch.experiment.tracking_metrics),
+        )
+        self.assertTrue("m1" in self.batch.experiment.metrics)
+        self.assertTrue("m2" in self.batch.experiment.metrics)
+
+        data = self.batch.lookup_data().df.to_dict(orient="index")
+        self.assertTrue(len(data) == 0)
+
+        # Attach data
+        self.batch.attach_batch_trial_data(
+            raw_data={
+                arm1_name: {"m1": 1.0, "m2": 2.0},
+                arm2_name: {"m1": 3.0, "m2": 4.0},
+            }
+        )
+
+        # Confirm the expected state after attaching data
+        data = (
+            self.batch.lookup_data()
+            .df.set_index(["arm_name", "metric_name"])
+            .to_dict(orient="index")
+        )
+
+        self.assertEqual(1.0, data[(arm1_name, "m1")]["mean"])
+        self.assertEqual(2.0, data[(arm1_name, "m2")]["mean"])
+        self.assertEqual(3.0, data[(arm2_name, "m1")]["mean"])
+        self.assertEqual(4.0, data[(arm2_name, "m2")]["mean"])
