@@ -145,6 +145,12 @@ class SearchSpaceExhausted(OptimizationComplete):
         )
 
 
+class IncompatibleDependencyVersion(AxError):
+    """Raise when an imcompatible dependency version is installed."""
+
+    pass
+
+
 class AxWarning(Warning):
     """Base Ax warning.
 
@@ -160,3 +166,9 @@ class AxWarning(Warning):
 
     def __str__(self) -> str:
         return " ".join([self.message, getattr(self, "hint", "")]).rstrip()
+
+
+class AxStorageWarning(AxWarning):
+    """Ax warning used for storage related concerns."""
+
+    pass
