@@ -14,6 +14,7 @@ from ax.core.experiment import Experiment
 from ax.core.optimization_config import OptimizationConfig
 from ax.core.parameter import ChoiceParameter, ParameterType, RangeParameter
 from ax.core.search_space import SearchSpace
+from ax.exceptions.core import UnsupportedError
 from ax.modelbridge.generation_strategy import GenerationStep, GenerationStrategy
 from ax.modelbridge.registry import Cont_X_trans, Models, Y_trans
 from ax.modelbridge.transforms.base import Transform
@@ -34,6 +35,7 @@ DEFAULT_BAYESIAN_PARALLELISM = 3
 # number of enumerated discrete combinations is below some maximum value.
 MAX_DISCRETE_ENUMERATIONS_MIXED = 65
 MAX_DISCRETE_ENUMERATIONS_NO_CONTINUOUS_OPTIMIZATION = 1e4
+MAX_ONE_HOT_ENCODINGS_CONTINUOUS_OPTIMIZATION = 33
 SAASBO_INCOMPATIBLE_MESSAGE = (
     "SAASBO is incompatible with {} generation strategy. "
     "Disregarding user input `use_saasbo = True`."
@@ -76,8 +78,10 @@ def _make_botorch_step(
     verbose: Optional[bool] = None,
     disable_progbar: Optional[bool] = None,
     derelativize_with_raw_status_quo: bool = False,
+    use_update: Optional[bool] = None,
 ) -> GenerationStep:
     """Shortcut for creating a BayesOpt generation step."""
+    model_kwargs = model_kwargs or {}
 
     winsorization_transform_config = _get_winsorization_transform_config(
         winsorization_config=winsorization_config,
@@ -88,27 +92,23 @@ def _make_botorch_step(
     derelativization_transform_config = {
         "use_raw_status_quo": derelativize_with_raw_status_quo
     }
+    model_kwargs["transform_configs"] = model_kwargs.get("transform_configs", {})
+    model_kwargs["transform_configs"][
+        "Derelativize"
+    ] = derelativization_transform_config
 
-    model_kwargs = model_kwargs or {}
     if not no_winsorization:
-        transforms = [cast(Type[Transform], Winsorize)] + Cont_X_trans + Y_trans
-        model_kwargs.update({"transforms": transforms})
+        transforms = model_kwargs.get("transforms", Cont_X_trans + Y_trans)
+        model_kwargs["transforms"] = [cast(Type[Transform], Winsorize)] + transforms
         if winsorization_transform_config is not None:
-            transform_configs = {
-                "Winsorize": winsorization_transform_config,
-                "Derelativize": derelativization_transform_config,
-            }
-            model_kwargs.update({"transform_configs": transform_configs})
+            model_kwargs["transform_configs"][
+                "Winsorize"
+            ] = winsorization_transform_config
 
     if verbose is not None:
         model_kwargs.update({"verbose": verbose})
     if disable_progbar is not None:
         model_kwargs.update({"disable_progbar": disable_progbar})
-    if is_saasbo(model):
-        logger.info(
-            "Setting `use_update=True` for SAASBO models. This will avoid "
-            " model re-fitting when there are no new completed trials."
-        )
     return GenerationStep(
         model=model,
         num_trials=num_trials,
@@ -116,7 +116,7 @@ def _make_botorch_step(
         min_trials_observed=min_trials_observed or ceil(num_trials / 2),
         enforce_num_trials=enforce_num_trials,
         max_parallelism=max_parallelism,
-        use_update=is_saasbo(model),
+        use_update=use_update if use_update is not None else is_saasbo(model),
         # `model_kwargs` should default to `None` if empty
         model_kwargs=model_kwargs if len(model_kwargs) > 0 else None,
         should_deduplicate=should_deduplicate,
@@ -139,18 +139,23 @@ def _suggest_gp_model(
     of discrete enumerations to be performed by the optimizer is less than
     ``MAX_DISCRETE_ENUMERATIONS_MIXED``, or if there are only choice parameters and
     the number of choice combinations to enumerate is less than
-    ``MAX_DISCRETE_ENUMERATIONS_CHOICE_ONLY``. ``BO_MIXED`` is not currently enabled
-    for multi-objective optimization.
-    3. We use ``MOO`` if ``optimization_config`` has multiple objectives and
-    ``use_saasbo is False``.
-    4. We use ``FULLYBAYESIANMOO`` if ``optimization_config`` has multiple objectives
-    and ``use_saasbo is True``.
-    5. If none of the above and ``use_saasbo is False``, we use ``GPEI``.
-    6. If none of the above and ``use_saasbo is True``, we use ``FULLYBAYESIAN``.
+    ``MAX_DISCRETE_ENUMERATIONS_CHOICE_ONLY``. Note that we do not count 2-level choice
+    parameters as unordered, since these do not affect the modeling choice.
+    3. If there are more ordered parameters in the search space than the sum of options
+    for the *unordered* choice parameters, or if there is at least one ordered
+    parameter and the number of parameters needed to encode all unordered parameters
+    is less than ``MAX_ONE_HOT_ENCODINGS_CONTINUOUS_OPTIMIZATION``, we use BO with
+    continuous relaxation.
+    * If ``optimization_config`` has multiple objectives, we use ``MOO`` if
+    ``use_saasbo is False`` and ``FULLYBAYESIANMOO`` otherwise.
+    * Otherwise, we use ``GPEI`` if ``use_saasbo is False`` and ``FULLYBAYESIAN``
+    otherwise.
     """
     # Count tunable parameter types.
-    num_ordered_parameters = num_unordered_choices = 0
-    num_enumerated_combinations = num_possible_points = 1
+    num_ordered_parameters = 0
+    num_unordered_choices = 0
+    num_enumerated_combinations = 1
+    num_possible_points = 1
     all_range_parameters_are_discrete = True
     all_parameters_are_enumerated = True
     for parameter in search_space.tunable_parameters.values():
@@ -160,7 +165,7 @@ def _suggest_gp_model(
             should_enumerate_param = True
             num_param_discrete_values = len(parameter.values)
             num_possible_points *= num_param_discrete_values
-            if parameter.is_ordered is False:
+            if parameter.is_ordered is False and num_param_discrete_values > 2:
                 num_unordered_choices += num_param_discrete_values
             else:
                 num_ordered_parameters += 1
@@ -188,23 +193,18 @@ def _suggest_gp_model(
             logger.warning(SAASBO_INCOMPATIBLE_MESSAGE.format("Sobol"))
         return None
 
-    is_moo_problem = optimization_config and optimization_config.is_moo_problem
-    if num_ordered_parameters > num_unordered_choices:
-        logger.info(
-            "Using Bayesian optimization since there are more ordered parameters than "
-            "there are categories for the unordered categorical parameters."
-        )
-        if is_moo_problem:
-            return Models.FULLYBAYESIANMOO if use_saasbo else Models.MOO
-        return Models.FULLYBAYESIAN if use_saasbo else Models.GPEI
-
     # Use mixed Bayesian optimization when appropriate. This logic is currently tied to
     # the fact that acquisition function optimization for mixed BayesOpt currently
     # enumerates all combinations of choice parameters.
-    if num_enumerated_combinations <= MAX_DISCRETE_ENUMERATIONS_MIXED or (
-        all_parameters_are_enumerated
-        and num_enumerated_combinations
-        < MAX_DISCRETE_ENUMERATIONS_NO_CONTINUOUS_OPTIMIZATION
+    # We use continuous relaxation if there are more ordered parameters than there
+    # are choices for unordered parameters.
+    if (num_ordered_parameters < num_unordered_choices) and (
+        num_enumerated_combinations <= MAX_DISCRETE_ENUMERATIONS_MIXED
+        or (
+            all_parameters_are_enumerated
+            and num_enumerated_combinations
+            < MAX_DISCRETE_ENUMERATIONS_NO_CONTINUOUS_OPTIMIZATION
+        )
     ):
         logger.info(
             "Using Bayesian optimization with a categorical kernel for improved "
@@ -214,6 +214,29 @@ def _suggest_gp_model(
             logger.warning(SAASBO_INCOMPATIBLE_MESSAGE.format("`BO_MIXED`"))
         return Models.BO_MIXED
 
+    is_moo_problem = optimization_config and optimization_config.is_moo_problem
+    if num_ordered_parameters >= num_unordered_choices or (
+        num_unordered_choices < MAX_ONE_HOT_ENCODINGS_CONTINUOUS_OPTIMIZATION
+        and num_ordered_parameters > 0
+    ):
+        # These use one-hot encoding for unordered choice parameters, resulting in a
+        # total of num_unordered_choices OHE parameters.
+        # So, we do not want to use them when there are too many unordered choices.
+        if is_moo_problem:
+            method = Models.FULLYBAYESIANMOO if use_saasbo else Models.MOO
+        else:
+            method = Models.FULLYBAYESIAN if use_saasbo else Models.GPEI
+        reason = (
+            "there are more ordered parameters than there are categories for the "
+            "unordered categorical parameters."
+            if num_ordered_parameters >= num_unordered_choices
+            else "there is at least one ordered parameter and there are fewer than "
+            f"{MAX_ONE_HOT_ENCODINGS_CONTINUOUS_OPTIMIZATION} choices for "
+            "unordered parameters."
+        )
+        logger.info(f"Using {method} since {reason}")
+        return method
+
     logger.info(
         f"Using Sobol since there are more than {MAX_DISCRETE_ENUMERATIONS_MIXED} "
         "combinations of enumerated parameters. For improved performance, make sure "
@@ -272,6 +295,7 @@ def choose_generation_strategy(
     verbose: Optional[bool] = None,
     disable_progbar: Optional[bool] = None,
     experiment: Optional[Experiment] = None,
+    use_update: Optional[bool] = None,
 ) -> GenerationStrategy:
     """Select an appropriate generation strategy based on the properties of
     the search space and expected settings of the experiment, such as number of
@@ -366,9 +390,28 @@ def choose_generation_strategy(
             strategy with a given experiment before it's first used to ``gen`` with
             that experiment). Can also provide `optimization_config` if it is not
             provided as an arg to this function.
+        use_update: Whether to use ``ModelBridge.update`` to update the model with
+            new data rather than fitting it from scratch. This is much more efficient,
+            particularly when running trials in parallel. Note that this is not
+            compatible with metrics that are available while running.
+            It will default to True if using SAASBO and the given experiment does not
+            have any metrics that are available while running.
     """
-    if optimization_config is None and experiment is not None:
-        optimization_config = experiment.optimization_config
+    if experiment is not None:
+        if optimization_config is None:
+            optimization_config = experiment.optimization_config
+        metrics_available_while_running = any(
+            m.is_available_while_running() for m in experiment.metrics.values()
+        )
+        if metrics_available_while_running:
+            if use_update is True:
+                raise UnsupportedError(
+                    "Got `use_update=True` but the experiment has metrics that are "
+                    "available while running. Set `use_update=False`."
+                )
+            else:
+                use_update = False
+
     suggested_model = _suggest_gp_model(
         search_space=search_space,
         num_trials=num_trials,
@@ -422,13 +465,13 @@ def choose_generation_strategy(
                 num_trials=num_trials,
                 use_batch_trials=use_batch_trials,
             )
+            if max_initialization_trials is not None:
+                num_initialization_trials = min(
+                    num_initialization_trials, max_initialization_trials
+                )
             logger.info(
                 f"calculated num_initialization_trials={num_initialization_trials}"
             )
-        if max_initialization_trials is not None:
-            num_initialization_trials = min(
-                num_initialization_trials, max_initialization_trials
-            )
         num_remaining_initialization_trials = max(
             0, num_initialization_trials - max(0, num_completed_initialization_trials)
         )
@@ -477,6 +520,7 @@ def choose_generation_strategy(
                 should_deduplicate=should_deduplicate,
                 verbose=verbose,
                 disable_progbar=disable_progbar,
+                use_update=use_update,
             ),
         )
         gs = GenerationStrategy(steps=steps)
