@@ -180,7 +180,31 @@ def extract_parameter_constraints(
 def extract_search_space_digest(
     search_space: SearchSpace, param_names: List[str]
 ) -> SearchSpaceDigest:
-    """Extract basic parameter properties from a search space."""
+    """Extract basic parameter properties from a search space.
+
+    This is typically called with the transformed search space and makes certain
+    assumptions regarding the parameters being transformed.
+
+    For ChoiceParameters:
+    * The choices are assumed to be numerical. ChoiceEncode and OrderedChoiceEncode
+    transforms handle this.
+    * If is_task, its index is added to task_features.
+    * If ordered, its index is added to ordinal_features.
+    * Otherwise, its index is added to categorical_features.
+    * In all cases, the choices are added to discrete_choices.
+    * The minimum and maximum value are added to the bounds.
+
+    For RangeParameters:
+    * They're assumed not to be in the log_scale. The Log transform handles this.
+    * If integer, its index is added to ordinal_features and the choices are added
+    to discrete_choices.
+    * The minimum and maximum value are added to the bounds.
+
+    If a parameter is_fidelity:
+    * Its target_value is assumed to be numerical.
+    * The target_value is added to target_fidelities.
+    * Its index is added to fidelity_features.
+    """
     bounds: List[Tuple[Union[int, float], Union[int, float]]] = []
     ordinal_features: List[int] = []
     categorical_features: List[int] = []
@@ -350,13 +374,10 @@ def extract_objective_thresholds(
     Will return None if no objective thresholds, otherwise the extracted tensor
     will be the same length as `outcomes`.
 
-    If one objective threshold is specified, they must be specified for every
-    metric in the objective.
-
-    Outcomes that are not part of an objective will be given a threshold of 0
-    in this tensor, under the assumption that its value will not be used. Note
-    that setting it to 0 for an outcome that is part of the objective would be
-    incorrect, hence we validate that all objective metrics are represented.
+    Outcomes that are not part of an objective and the objectives that do no have
+    a corresponding objective threshold will be given a threshold of NaN. We will
+    later infer appropriate threshold values for the objectives that are given a
+    threshold of NaN.
 
     Args:
         objective_thresholds: Objective thresholds to extract values from.
@@ -378,20 +399,18 @@ def extract_objective_thresholds(
             )
         objective_threshold_dict[ot.metric.name] = ot.bound
 
-    if len(objective_threshold_dict) != len(objective.metrics):
+    # Check that all thresholds correspond to a metric.
+    if set(objective_threshold_dict.keys()).difference(set(objective.metric_names)):
         raise ValueError(
-            "Objective thresholds do not match number of objective metrics."
+            "Some objective thresholds do not have corresponding metrics."
+            f"Got {objective_thresholds=} and {objective=}."
         )
-    # Initialize these to be nan to make sure that objective thresholds for
-    # non-objective metrics are never used
+
+    # Initialize these to be NaN to make sure that objective thresholds for
+    # non-objective metrics are never used.
     obj_t = np.full(len(outcomes), float("nan"))
-    for metric in objective.metrics:
-        if metric.name not in objective_threshold_dict:
-            raise ValueError(  # pragma: no cover
-                f"Objective threshold not specified for {metric.name}. Thresholds must "
-                f"be specified for all objective metrics or for none."
-            )
-        obj_t[outcomes.index(metric.name)] = objective_threshold_dict[metric.name]
+    for metric, threshold in objective_threshold_dict.items():
+        obj_t[outcomes.index(metric)] = threshold
     return obj_t
 
 
@@ -503,9 +522,11 @@ def validate_and_apply_final_transform(
 
 
 def get_fixed_features(
-    fixed_features: ObservationFeatures, param_names: List[str]
+    fixed_features: Optional[ObservationFeatures], param_names: List[str]
 ) -> Optional[Dict[int, float]]:
     """Reformat a set of fixed_features."""
+    if fixed_features is None:
+        return None
     fixed_features_dict = {}
     for p_name, val in fixed_features.parameters.items():
         # These all need to be floats at this point.
@@ -911,7 +932,8 @@ def get_pareto_frontier_and_configs(
         objective=optimization_config.objective,
         outcomes=modelbridge.outcomes,
     )
-    obj_t = array_to_tensor(obj_t)
+    if obj_t is not None:
+        obj_t = array_to_tensor(obj_t)
     # Transform to tensors.
     obj_w, oc_c, _, _, _ = validate_and_apply_final_transform(
         objective_weights=objective_weights,
@@ -945,7 +967,12 @@ def get_pareto_frontier_and_configs(
             )
         )
 
-    return frontier_observations, f, obj_w.cpu(), obj_t.cpu()
+    return (
+        frontier_observations,
+        f,
+        obj_w.cpu(),
+        obj_t.cpu() if obj_t is not None else None,
+    )
 
 
 def pareto_frontier(
@@ -1234,8 +1261,10 @@ def observed_hypervolume(
 
     Args:
         modelbridge: Modelbridge that holds previous training data.
-        objective_thresholds: point defining the origin of hyperrectangles that
-            can contribute to hypervolume.
+        objective_thresholds: Point defining the origin of hyperrectangles that
+            can contribute to hypervolume. Note that if this is None,
+            `objective_thresholds` must be present on the
+            `modelbridge.optimization_config`.
         observation_features: observation features to predict. Model's training
             data used by default if unspecified.
         optimization_config: Optimization config
