@@ -7,28 +7,34 @@
 import logging
 import warnings
 from typing import Any, Dict
+from unittest import mock
 
 import torch
 from ax.core.objective import MultiObjective
 from ax.core.optimization_config import MultiObjectiveOptimizationConfig
+from ax.exceptions.core import UnsupportedError
 from ax.modelbridge.dispatch_utils import (
+    _make_botorch_step,
     calculate_num_initialization_trials,
     choose_generation_strategy,
     DEFAULT_BAYESIAN_PARALLELISM,
 )
 from ax.modelbridge.factory import Cont_X_trans, Y_trans
 from ax.modelbridge.registry import Models
+from ax.modelbridge.transforms.log_y import LogY
 from ax.modelbridge.transforms.winsorize import Winsorize
 from ax.models.winsorization_config import WinsorizationConfig
 from ax.utils.common.testutils import TestCase
 from ax.utils.common.typeutils import not_none
 from ax.utils.testing.core_stubs import (
+    get_branin_experiment,
     get_branin_search_space,
     get_discrete_search_space,
     get_experiment,
     get_factorial_search_space,
     get_large_factorial_search_space,
     get_large_ordinal_search_space,
+    get_search_space_with_choice_parameters,
 )
 
 
@@ -70,6 +76,24 @@ class TestDispatchUtils(TestCase):
             self.assertEqual(sobol_gpei._steps[0].model, Models.SOBOL)
             self.assertEqual(sobol_gpei._steps[0].num_trials, 2)
             self.assertEqual(sobol_gpei._steps[1].model, Models.GPEI)
+        with self.subTest("num_initialization_trials > max_initialization_trials"):
+            sobol_gpei = choose_generation_strategy(
+                search_space=get_branin_search_space(),
+                max_initialization_trials=2,
+                num_initialization_trials=3,
+            )
+            self.assertEqual(sobol_gpei._steps[0].model, Models.SOBOL)
+            self.assertEqual(sobol_gpei._steps[0].num_trials, 3)
+            self.assertEqual(sobol_gpei._steps[1].model, Models.GPEI)
+        with self.subTest("num_initialization_trials > max_initialization_trials"):
+            sobol_gpei = choose_generation_strategy(
+                search_space=get_branin_search_space(),
+                max_initialization_trials=2,
+                num_initialization_trials=3,
+            )
+            self.assertEqual(sobol_gpei._steps[0].model, Models.SOBOL)
+            self.assertEqual(sobol_gpei._steps[0].num_trials, 3)
+            self.assertEqual(sobol_gpei._steps[1].model, Models.GPEI)
         with self.subTest("MOO"):
             optimization_config = MultiObjectiveOptimizationConfig(
                 objective=MultiObjective(objectives=[])
@@ -83,8 +107,8 @@ class TestDispatchUtils(TestCase):
             self.assertEqual(sobol_gpei._steps[1].model, Models.MOO)
             model_kwargs = not_none(sobol_gpei._steps[1].model_kwargs)
             self.assertEqual(
-                list(model_kwargs.keys()),
-                ["torch_device", "transforms", "transform_configs"],
+                set(model_kwargs.keys()),
+                {"torch_device", "transforms", "transform_configs"},
             )
             self.assertGreater(len(model_kwargs["transforms"]), 0)
         with self.subTest("Sobol (we can try every option)"):
@@ -94,14 +118,12 @@ class TestDispatchUtils(TestCase):
             self.assertEqual(sobol._steps[0].model, Models.SOBOL)
             self.assertEqual(len(sobol._steps), 1)
         with self.subTest("Sobol (because of too many categories)"):
-            ss = get_large_factorial_search_space()
             sobol_large = choose_generation_strategy(
                 search_space=get_large_factorial_search_space(), verbose=True
             )
             self.assertEqual(sobol_large._steps[0].model, Models.SOBOL)
             self.assertEqual(len(sobol_large._steps), 1)
         with self.subTest("Sobol (because of too many categories) with saasbo"):
-            ss = get_large_factorial_search_space()
             with self.assertLogs(
                 choose_generation_strategy.__module__, logging.WARNING
             ) as logger:
@@ -119,6 +141,33 @@ class TestDispatchUtils(TestCase):
                 )
             self.assertEqual(sobol_large._steps[0].model, Models.SOBOL)
             self.assertEqual(len(sobol_large._steps), 1)
+        with self.subTest("SOBOL due to too many unordered choices"):
+            # Search space with more unordered choices than ordered parameters.
+            sobol = choose_generation_strategy(
+                search_space=get_search_space_with_choice_parameters(
+                    num_ordered_parameters=5,
+                    num_unordered_choices=100,
+                )
+            )
+            self.assertEqual(sobol._steps[0].model, Models.SOBOL)
+            self.assertEqual(len(sobol._steps), 1)
+        with self.subTest("GPEI with more unordered choices than ordered parameters"):
+            # Search space with more unordered choices than ordered parameters.
+            sobol_gpei = choose_generation_strategy(
+                search_space=get_search_space_with_choice_parameters(
+                    num_ordered_parameters=5,
+                    num_unordered_choices=10,
+                )
+            )
+            self.assertEqual(sobol_gpei._steps[1].model, Models.GPEI)
+        with self.subTest("GPEI despite many unordered 2-value parameters"):
+            gs = choose_generation_strategy(
+                search_space=get_large_factorial_search_space(
+                    num_levels=2, num_parameters=10
+                ),
+            )
+            self.assertEqual(gs._steps[0].model, Models.SOBOL)
+            self.assertEqual(gs._steps[1].model, Models.GPEI)
         with self.subTest("GPEI-Batched"):
             sobol_gpei_batched = choose_generation_strategy(
                 search_space=get_branin_search_space(),
@@ -166,8 +215,8 @@ class TestDispatchUtils(TestCase):
             self.assertEqual(moo_mixed._steps[1].model, Models.BO_MIXED)
             model_kwargs = not_none(moo_mixed._steps[1].model_kwargs)
             self.assertEqual(
-                list(model_kwargs.keys()),
-                ["torch_device", "transforms", "transform_configs"],
+                set(model_kwargs.keys()),
+                {"torch_device", "transforms", "transform_configs"},
             )
             self.assertGreater(len(model_kwargs["transforms"]), 0)
         with self.subTest("SAASBO"):
@@ -243,6 +292,26 @@ class TestDispatchUtils(TestCase):
             self.assertEqual(gs_6_init_trials._steps[0].num_trials, 6)
             self.assertEqual(gs_6_init_trials._steps[1].model, Models.GPEI)
 
+    def test_make_botorch_step_extra(self) -> None:
+        # Test parts of _make_botorch_step that are not directly exposed in
+        # choose_generation_strategy.
+        model_kwargs = {
+            "transforms": [LogY],
+            "transform_configs": {"LogY": {"metrics": ["metric_1"]}},
+        }
+        bo_step = _make_botorch_step(model_kwargs=model_kwargs)
+        self.assertEqual(
+            not_none(bo_step.model_kwargs)["transforms"], [Winsorize, LogY]
+        )
+        self.assertEqual(
+            not_none(bo_step.model_kwargs)["transform_configs"],
+            {
+                "LogY": {"metrics": ["metric_1"]},
+                "Derelativize": {"use_raw_status_quo": False},
+                "Winsorize": {"derelativize_with_raw_status_quo": False},
+            },
+        )
+
     def test_disable_progbar(self) -> None:
         for disable_progbar in (True, False):
             with self.subTest(str(disable_progbar)):
@@ -427,9 +496,8 @@ class TestDispatchUtils(TestCase):
             self.assertIn("Not winsorizing", str(w[-1].message))
 
         self.assertNotIn(
-            # transform_configs would have "Winsorize" if it existed
-            "transform_configs",
-            set(not_none(unwinsorized._steps[1].model_kwargs)),
+            "Winsorize",
+            not_none(unwinsorized._steps[1].model_kwargs)["transform_configs"],
         )
 
     def test_num_trials(self) -> None:
@@ -441,7 +509,7 @@ class TestDispatchUtils(TestCase):
             self.assertEqual(sobol_gpei._steps[0].model, Models.SOBOL)
             self.assertEqual(sobol_gpei._steps[1].model, Models.BO_MIXED)
         with self.subTest("with budget that is exhaustive, Sobol is used"):
-            sobol = choose_generation_strategy(search_space=ss, num_trials=24)
+            sobol = choose_generation_strategy(search_space=ss, num_trials=36)
             self.assertEqual(sobol._steps[0].model, Models.SOBOL)
             self.assertEqual(len(sobol._steps), 1)
         with self.subTest("with budget that is exhaustive and use_saasbo, it warns"):
@@ -450,7 +518,7 @@ class TestDispatchUtils(TestCase):
             ) as logger:
                 sobol = choose_generation_strategy(
                     search_space=ss,
-                    num_trials=24,
+                    num_trials=36,
                     use_saasbo=True,
                 )
                 self.assertTrue(
@@ -613,3 +681,48 @@ class TestDispatchUtils(TestCase):
                 ),
                 5,
             )
+
+    def test_use_update(self) -> None:
+        search_space = get_branin_search_space()
+        # No experiment, no SAAS, default to False.
+        gs = choose_generation_strategy(search_space=search_space)
+        self.assertFalse(gs._steps[1].use_update)
+        # Pass in True.
+        gs = choose_generation_strategy(search_space=search_space, use_update=True)
+        self.assertTrue(gs._steps[1].use_update)
+        # With experiment without any metrics available while running.
+        experiment = get_branin_experiment()
+        with mock.patch.object(
+            experiment.metrics["branin"],
+            "is_available_while_running",
+            return_value=False,
+        ):
+            # No SAAS, default to False.
+            gs = choose_generation_strategy(
+                search_space=search_space, experiment=experiment
+            )
+            self.assertFalse(gs._steps[1].use_update)
+            # SAAS, default to True.
+            gs = choose_generation_strategy(
+                search_space=search_space, experiment=experiment, use_saasbo=True
+            )
+            self.assertTrue(gs._steps[1].use_update)
+            # SAAS and pass in False.
+            gs = choose_generation_strategy(
+                search_space=search_space,
+                experiment=experiment,
+                use_saasbo=True,
+                use_update=False,
+            )
+            self.assertFalse(gs._steps[1].use_update)
+        # SAAS with metrics available while running.
+        gs = choose_generation_strategy(
+            search_space=search_space, experiment=experiment, use_saasbo=True
+        )
+        # Default to False.
+        self.assertFalse(gs._steps[1].use_update)
+        # Error with True.
+        with self.assertRaisesRegex(UnsupportedError, "use_update"):
+            choose_generation_strategy(
+                search_space=search_space, experiment=experiment, use_update=True
+            )
