@@ -38,10 +38,12 @@ from ax.models.torch.botorch_moo_defaults import (
 )
 from ax.service.utils.report_utils import exp_to_df
 from ax.utils.common.testutils import TestCase
-from ax.utils.common.typeutils import not_none
+from ax.utils.common.typeutils import checked_cast, not_none
 from ax.utils.testing.core_stubs import (
     get_branin_data_multi_objective,
     get_branin_experiment_with_multi_objective,
+    get_hierarchical_search_space,
+    get_hss_trials_with_fixed_parameter,
     get_non_monolithic_branin_moo_data,
     TEST_SOBOL_SEED,
 )
@@ -193,12 +195,16 @@ class MultiObjectiveTorchModelBridgeTest(TestCase):
         )
         self.assertEqual(observed_frontier, observed_frontier2)
 
+        # Remove the thresholds for testing None handling.
+        checked_cast(
+            MultiObjectiveOptimizationConfig, modelbridge._optimization_config
+        )._objective_thresholds = []
         with patch(
             PARETO_FRONTIER_EVALUATOR_PATH, wraps=pareto_frontier_evaluator
         ) as wrapped_frontier_evaluator:
             (observed_frontier, f, obj_w, obj_t,) = get_pareto_frontier_and_configs(
                 modelbridge=modelbridge,
-                objective_thresholds=objective_thresholds,
+                objective_thresholds=None,
                 observation_features=observation_features,
                 observation_data=observation_data,
                 use_model_predictions=False,
@@ -213,6 +219,7 @@ class MultiObjectiveTorchModelBridgeTest(TestCase):
             )
         )
         self.assertTrue(torch.equal(f[:, :2], true_Y[1:, :]))
+        self.assertIsNone(obj_t)
 
     def test_pareto_frontier(self) -> None:
         """
@@ -473,93 +480,106 @@ class MultiObjectiveTorchModelBridgeTest(TestCase):
             ParameterConstraint(constraint_dict={"x1": 1.0}, bound=10.0)
         ]
         search_space.add_parameter_constraints(param_constraints)
-        # pyre-fixme[16]: Optional type has no attribute `clone`.
-        oc = exp.optimization_config.clone()
+        oc = not_none(exp.optimization_config).clone()
         oc.objective._objectives[0].minimize = True
-        expected_base_gen_args = modelbridge._get_transformed_gen_args(
-            search_space=search_space.clone(),
-            optimization_config=oc,
-            fixed_features=fixed_features,
-        )
-        with ExitStack() as es:
-            mock_model_infer_obj_t = es.enter_context(
-                patch(
-                    "ax.modelbridge.torch.infer_objective_thresholds",
-                    wraps=infer_objective_thresholds,
-                )
-            )
-            mock_get_transformed_gen_args = es.enter_context(
-                patch.object(
-                    modelbridge,
-                    "_get_transformed_gen_args",
-                    wraps=modelbridge._get_transformed_gen_args,
-                )
-            )
-            mock_get_transformed_model_gen_args = es.enter_context(
-                patch.object(
-                    modelbridge,
-                    "_get_transformed_model_gen_args",
-                    wraps=modelbridge._get_transformed_model_gen_args,
-                )
-            )
-            mock_untransform_objective_thresholds = es.enter_context(
-                patch.object(
-                    modelbridge,
-                    "_untransform_objective_thresholds",
-                    wraps=modelbridge._untransform_objective_thresholds,
-                )
-            )
-            obj_thresholds = modelbridge.infer_objective_thresholds(
-                search_space=search_space,
+
+        for use_partial_thresholds in (False, True):
+            if use_partial_thresholds:
+                checked_cast(
+                    MultiObjectiveOptimizationConfig, oc
+                )._objective_thresholds = [
+                    ObjectiveThreshold(
+                        metric=oc.objective.metrics[0],
+                        bound=2.0,
+                        relative=False,
+                        op=ComparisonOp.LEQ,
+                    )
+                ]
+            expected_base_gen_args = modelbridge._get_transformed_gen_args(
+                search_space=search_space.clone(),
                 optimization_config=oc,
                 fixed_features=fixed_features,
             )
-            expected_obj_weights = torch.tensor([-1.0, 1.0], dtype=torch.double)
-            ckwargs = mock_model_infer_obj_t.call_args[1]
-            self.assertTrue(
-                torch.equal(ckwargs["objective_weights"], expected_obj_weights)
-            )
-            # check that transforms have been applied (at least UnitX)
-            self.assertEqual(ckwargs["bounds"], [(0.0, 1.0), (0.0, 1.0)])
-            lc = ckwargs["linear_constraints"]
-            self.assertTrue(
-                torch.equal(lc[0], torch.tensor([[15.0, 0.0]], dtype=torch.double))
-            )
-            self.assertTrue(
-                torch.equal(lc[1], torch.tensor([[15.0]], dtype=torch.double))
-            )
-            self.assertEqual(ckwargs["fixed_features"], {0: 1.0 / 3.0})
-            mock_get_transformed_gen_args.assert_called_once()
-            mock_get_transformed_model_gen_args.assert_called_once_with(
-                search_space=expected_base_gen_args.search_space,
-                fixed_features=expected_base_gen_args.fixed_features,
-                pending_observations=expected_base_gen_args.pending_observations,
-                optimization_config=expected_base_gen_args.optimization_config,
-            )
-            mock_untransform_objective_thresholds.assert_called_once()
-            ckwargs = mock_untransform_objective_thresholds.call_args[1]
+            with ExitStack() as es:
+                mock_model_infer_obj_t = es.enter_context(
+                    patch(
+                        "ax.modelbridge.torch.infer_objective_thresholds",
+                        wraps=infer_objective_thresholds,
+                    )
+                )
+                mock_get_transformed_gen_args = es.enter_context(
+                    patch.object(
+                        modelbridge,
+                        "_get_transformed_gen_args",
+                        wraps=modelbridge._get_transformed_gen_args,
+                    )
+                )
+                mock_get_transformed_model_gen_args = es.enter_context(
+                    patch.object(
+                        modelbridge,
+                        "_get_transformed_model_gen_args",
+                        wraps=modelbridge._get_transformed_model_gen_args,
+                    )
+                )
+                mock_untransform_objective_thresholds = es.enter_context(
+                    patch.object(
+                        modelbridge,
+                        "_untransform_objective_thresholds",
+                        wraps=modelbridge._untransform_objective_thresholds,
+                    )
+                )
+                obj_thresholds = modelbridge.infer_objective_thresholds(
+                    search_space=search_space,
+                    optimization_config=oc,
+                    fixed_features=fixed_features,
+                )
+                expected_obj_weights = torch.tensor([-1.0, 1.0], dtype=torch.double)
+                ckwargs = mock_model_infer_obj_t.call_args[1]
+                self.assertTrue(
+                    torch.equal(ckwargs["objective_weights"], expected_obj_weights)
+                )
+                # check that transforms have been applied (at least UnitX)
+                self.assertEqual(ckwargs["bounds"], [(0.0, 1.0), (0.0, 1.0)])
+                lc = ckwargs["linear_constraints"]
+                self.assertTrue(
+                    torch.equal(lc[0], torch.tensor([[15.0, 0.0]], dtype=torch.double))
+                )
+                self.assertTrue(
+                    torch.equal(lc[1], torch.tensor([[15.0]], dtype=torch.double))
+                )
+                self.assertEqual(ckwargs["fixed_features"], {0: 1.0 / 3.0})
+                mock_get_transformed_gen_args.assert_called_once()
+                mock_get_transformed_model_gen_args.assert_called_once_with(
+                    search_space=expected_base_gen_args.search_space,
+                    fixed_features=expected_base_gen_args.fixed_features,
+                    pending_observations=expected_base_gen_args.pending_observations,
+                    optimization_config=expected_base_gen_args.optimization_config,
+                )
+                mock_untransform_objective_thresholds.assert_called_once()
+                ckwargs = mock_untransform_objective_thresholds.call_args[1]
 
+                self.assertTrue(
+                    torch.equal(ckwargs["objective_weights"], expected_obj_weights)
+                )
+            self.assertEqual(obj_thresholds[0].metric.name, "branin_a")
+            self.assertEqual(obj_thresholds[1].metric.name, "branin_b")
+            self.assertEqual(obj_thresholds[0].op, ComparisonOp.LEQ)
+            self.assertEqual(obj_thresholds[1].op, ComparisonOp.GEQ)
+            self.assertFalse(obj_thresholds[0].relative)
+            self.assertFalse(obj_thresholds[1].relative)
+            df = exp_to_df(exp)
+            Y = np.stack([df.branin_a.values, df.branin_b.values]).T
+            Y = torch.from_numpy(Y)
+            Y[:, 0] *= -1
+            pareto_Y = Y[is_non_dominated(Y)]
+            nadir = pareto_Y.min(dim=0).values
             self.assertTrue(
-                torch.equal(ckwargs["objective_weights"], expected_obj_weights)
+                np.all(
+                    np.array([-obj_thresholds[0].bound, obj_thresholds[1].bound])
+                    < nadir.numpy()
+                )
             )
-        self.assertEqual(obj_thresholds[0].metric.name, "branin_a")
-        self.assertEqual(obj_thresholds[1].metric.name, "branin_b")
-        self.assertEqual(obj_thresholds[0].op, ComparisonOp.LEQ)
-        self.assertEqual(obj_thresholds[1].op, ComparisonOp.GEQ)
-        self.assertFalse(obj_thresholds[0].relative)
-        self.assertFalse(obj_thresholds[1].relative)
-        df = exp_to_df(exp)
-        Y = np.stack([df.branin_a.values, df.branin_b.values]).T
-        Y = torch.from_numpy(Y)
-        Y[:, 0] *= -1
-        pareto_Y = Y[is_non_dominated(Y)]
-        nadir = pareto_Y.min(dim=0).values
-        self.assertTrue(
-            np.all(
-                np.array([-obj_thresholds[0].bound, obj_thresholds[1].bound])
-                < nadir.numpy()
-            )
-        )
+
         # test using MTGP
         sobol_generator = get_sobol(
             search_space=exp.search_space,
@@ -631,6 +651,48 @@ class MultiObjectiveTorchModelBridgeTest(TestCase):
             )
         )
 
+        # test with HSS
+        hss = get_hierarchical_search_space(with_fixed_parameter=True)
+        exp = get_branin_experiment_with_multi_objective(has_optimization_config=True)
+        data = get_branin_data_multi_objective(trial_indices=[0, 1])
+        # Update trials to match the search space.
+        exp._search_space = hss
+        exp._trials = get_hss_trials_with_fixed_parameter(exp=exp)
+        modelbridge = TorchModelBridge(
+            search_space=hss,
+            model=MultiObjectiveBotorchModel(),
+            optimization_config=exp.optimization_config,
+            transforms=Cont_X_trans + Y_trans,
+            torch_device=torch.device("cuda" if cuda else "cpu"),
+            experiment=exp,
+            data=data,
+            # [T143911996] The trials get ignored without fit_out_of_design.
+            fit_out_of_design=True,
+        )
+        self.assertIn("Cast", modelbridge.transforms)
+        with patch.object(
+            modelbridge,
+            "_untransform_objective_thresholds",
+            wraps=modelbridge._untransform_objective_thresholds,
+        ) as mock_untransform, patch.object(
+            modelbridge.transforms["Cast"],
+            "untransform_observation_features",
+            wraps=modelbridge.transforms["Cast"].untransform_observation_features,
+        ) as wrapped_cast:
+            obj_thresholds = modelbridge.infer_objective_thresholds(
+                search_space=hss,
+                optimization_config=exp.optimization_config,
+                fixed_features=None,
+            )
+        mock_untransform.assert_called_once()
+        self.assertEqual(wrapped_cast.call_count, 0)
+        self.assertEqual(obj_thresholds[0].metric.name, "branin_a")
+        self.assertEqual(obj_thresholds[1].metric.name, "branin_b")
+        self.assertEqual(obj_thresholds[0].op, ComparisonOp.GEQ)
+        self.assertEqual(obj_thresholds[1].op, ComparisonOp.GEQ)
+        self.assertFalse(obj_thresholds[0].relative)
+        self.assertFalse(obj_thresholds[1].relative)
+
     @fast_botorch_optimize
     def test_status_quo_for_non_monolithic_data(self) -> None:
         exp = get_branin_experiment_with_multi_objective(with_status_quo=True)
