@@ -55,6 +55,7 @@ from ax.modelbridge.modelbridge_utils import (
     validate_and_apply_final_transform,
 )
 from ax.modelbridge.transforms.base import Transform
+from ax.modelbridge.transforms.cast import Cast
 from ax.models.torch.botorch_modular.model import BoTorchModel
 from ax.models.torch.botorch_moo import MultiObjectiveBotorchModel
 from ax.models.torch.botorch_moo_defaults import infer_objective_thresholds
@@ -520,7 +521,7 @@ class TorchModelBridge(ModelBridge):
         n: int,
         search_space: SearchSpace,
         pending_observations: Dict[str, List[ObservationFeatures]],
-        fixed_features: ObservationFeatures,
+        fixed_features: Optional[ObservationFeatures],
         model_gen_options: Optional[TConfig] = None,
         optimization_config: Optional[OptimizationConfig] = None,
     ) -> GenResults:
@@ -612,6 +613,14 @@ class TorchModelBridge(ModelBridge):
         f, cov = not_none(self.model).predict(X=self._array_to_tensor(X))
         f = f.detach().cpu().clone().numpy()
         cov = cov.detach().cpu().clone().numpy()
+        if f.shape[-2] != X.shape[-2]:
+            raise NotImplementedError(
+                "Expected same number of predictions as the number of inputs but got "
+                f"predictions of shape {f.shape} for inputs of shape {X.shape}. "
+                "This was likely due to the use of one-to-many input transforms -- "
+                "typically used for robust optimization -- which are not supported in"
+                "TorchModelBridge.predict."
+            )
         # Convert resulting arrays to observations
         return array_to_observation_data(f=f, cov=cov, outcomes=self.outcomes)
 
@@ -645,7 +654,7 @@ class TorchModelBridge(ModelBridge):
         self,
         search_space: SearchSpace,
         pending_observations: Dict[str, List[ObservationFeatures]],
-        fixed_features: ObservationFeatures,
+        fixed_features: Optional[ObservationFeatures],
         model_gen_options: Optional[TConfig] = None,
         optimization_config: Optional[OptimizationConfig] = None,
     ) -> Tuple[SearchSpaceDigest, TorchOptConfig]:
@@ -780,9 +789,12 @@ class TorchModelBridge(ModelBridge):
         )
 
         for t in reversed(list(self.transforms.values())):
-            fixed_features_obs = t.untransform_observation_features(
-                [fixed_features_obs]
-            )[0]
+            if not isinstance(t, Cast):
+                # Cast transform requires a valid hierarchical parameterization.
+                # `fixed_features_obs` is incomplete, so it leads to an error.
+                fixed_features_obs = t.untransform_observation_features(
+                    [fixed_features_obs]
+                )[0]
             thresholds = t.untransform_outcome_constraints(
                 outcome_constraints=thresholds,
                 fixed_features=fixed_features_obs,
