@@ -10,9 +10,11 @@ import numpy as np
 from ax.core.observation import ObservationFeatures
 from ax.core.optimization_config import OptimizationConfig
 from ax.core.outcome_constraint import OutcomeConstraint, ScalarizedOutcomeConstraint
+from ax.exceptions.core import DataRequiredError
 from ax.modelbridge.base import unwrap_observation_data
 from ax.modelbridge.transforms.base import Transform
 from ax.modelbridge.transforms.ivw import ivw_metric_merge
+from ax.utils.common.typeutils import not_none
 
 
 if TYPE_CHECKING:
@@ -51,8 +53,9 @@ class Derelativize(Transform):
         # Estimate the value at the status quo.
         if modelbridge is None:
             raise ValueError("ModelBridge not supplied to transform.")
+        # Unobserved status quo corresponds to a modelbridge.status_quo of None.
         if modelbridge.status_quo is None:
-            raise ValueError(
+            raise DataRequiredError(
                 "Optimization config has relative constraint, but model was "
                 "not fit with status quo."
             )
@@ -65,8 +68,7 @@ class Derelativize(Transform):
             ):
                 # Out-of-design: use the raw observation
                 sq_data = ivw_metric_merge(
-                    # pyre-fixme[16]: `Optional` has no attribute `data`.
-                    obsd=modelbridge.status_quo.data,
+                    obsd=not_none(modelbridge.status_quo).data,
                     conflicting_noiseless="raise",
                 )
                 f, _ = unwrap_observation_data([sq_data])
@@ -78,6 +80,14 @@ class Derelativize(Transform):
         for c in optimization_config.all_constraints:
             if c.relative:
                 if isinstance(c, ScalarizedOutcomeConstraint):
+                    missing_metrics = {
+                        metric.name for metric in c.metrics if metric.name not in f
+                    }
+                    if len(missing_metrics) > 0:
+                        raise DataRequiredError(
+                            f"Status-quo metric value not yet available for metric(s) "
+                            f"{missing_metrics}."
+                        )
                     # The sq_val of scalarized outcome is the weighted
                     # sum of its component metrics
                     sq_val = np.sum(
@@ -86,8 +96,13 @@ class Derelativize(Transform):
                             for i, metric in enumerate(c.metrics)
                         ]
                     )
-                else:
+                elif c.metric.name in f:
                     sq_val = f[c.metric.name][0]
+                else:
+                    raise DataRequiredError(
+                        f"Status-quo metric value not yet available for metric "
+                        f"{c.metric.name}."
+                    )
                 c.bound = (1 + c.bound / 100.0) * sq_val
                 c.relative = False
         return optimization_config
