@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -9,10 +9,11 @@ import json
 from typing import Dict, List, Optional, Tuple
 
 import numpy as np
-from ax.core.types import TConfig, TGenMetadata, TParamValue, TParamValueList
+from ax.core.types import TGenMetadata, TParamValue, TParamValueList
 from ax.exceptions.constants import TS_MIN_WEIGHT_ERROR, TS_NO_FEASIBLE_ARMS_ERROR
 from ax.exceptions.model import ModelError
 from ax.models.discrete_base import DiscreteModel
+from ax.models.types import TConfig
 from ax.utils.common.docutils import copy_doc
 
 
@@ -43,9 +44,13 @@ class ThompsonSampler(DiscreteModel):
         self.min_weight = min_weight
         self.uniform_weights = uniform_weights
 
+        # pyre-fixme[4]: Attribute must be annotated.
         self.X = None
+        # pyre-fixme[4]: Attribute must be annotated.
         self.Ys = None
+        # pyre-fixme[4]: Attribute must be annotated.
         self.Yvars = None
+        # pyre-fixme[4]: Attribute must be annotated.
         self.X_to_Ys_and_Yvars = None
 
     @copy_doc(DiscreteModel.fit)
@@ -91,8 +96,6 @@ class ThompsonSampler(DiscreteModel):
         weighted_arms = [
             (weights[i], np.random.random(), arms[i])
             for i in range(k)
-            # pyre-fixme[58]: `>` is not supported for operand types `float` and
-            #  `Optional[float]`.
             if weights[i] > min_weight
         ]
 
@@ -169,12 +172,7 @@ class ThompsonSampler(DiscreteModel):
         weights = winner_counts / winner_counts.sum()
         return weights.tolist()
 
-    def _produce_samples(
-        self,
-        num_samples: int,
-        objective_weights: np.ndarray,
-        outcome_constraints: Optional[Tuple[np.ndarray, np.ndarray]],
-    ) -> Tuple[np.ndarray, float]:
+    def _generate_samples_per_metric(self, num_samples: int) -> np.ndarray:
         k = len(self.X)
         samples_per_metric = np.zeros(
             (k, num_samples, len(self.Ys))
@@ -186,6 +184,16 @@ class ThompsonSampler(DiscreteModel):
                 Y, cov, num_samples
             ).T  # (k x num_samples)
             samples_per_metric[:, :, i] = samples
+        return samples_per_metric
+
+    def _produce_samples(
+        self,
+        num_samples: int,
+        objective_weights: np.ndarray,
+        outcome_constraints: Optional[Tuple[np.ndarray, np.ndarray]],
+    ) -> Tuple[np.ndarray, float]:
+        k = len(self.X)
+        samples_per_metric = self._generate_samples_per_metric(num_samples=num_samples)
 
         any_violation = np.zeros((k, num_samples), dtype=bool)  # (k x num_samples)
         if outcome_constraints:
