@@ -20,6 +20,7 @@ from ax.models.model_utils import (
 from ax.models.types import TConfig
 from ax.utils.common.docutils import copy_doc
 from ax.utils.common.logger import get_logger
+from ax.utils.common.typeutils import checked_cast
 from botorch.utils.sampling import HitAndRunPolytopeSampler
 from torch import Tensor
 
@@ -58,7 +59,11 @@ class RandomModel(Model):
     ) -> None:
         super().__init__()
         self.deduplicate = deduplicate
-        self.seed = seed
+        self.seed: int = (
+            seed
+            if seed is not None
+            else checked_cast(int, torch.randint(high=100_000, size=(1,)).item())
+        )
         # Used for deduplication.
         self.generated_points = generated_points
         self.fallback_to_sample_polytope = fallback_to_sample_polytope
@@ -113,8 +118,7 @@ class RandomModel(Model):
                 #  for 1st param but got
                 #  `Union[botorch.acquisition.acquisition.AcquisitionFunction, float,
                 #  int, str]`.
-                # pyre-fixme[35]: Target cannot be annotated.
-                max_draws: int = int(max_draws)
+                max_draws = int(max_draws)
         try:
             # Always rejection sample, but this only rejects if there are
             # constraints or actual duplicates and deduplicate is specified.
@@ -135,7 +139,8 @@ class RandomModel(Model):
             if self.fallback_to_sample_polytope:
                 logger.info(
                     "Rejection sampling exceeded specified maximum draws."
-                    "Falling back on polytope sampler"
+                    "Falling back on HitAndRunPolytopeSampler instead of "
+                    f"{self.__class__.__name__}."
                 )
                 # If rejection sampling fails, try polytope sampler.
                 polytope_sampler = HitAndRunPolytopeSampler(
@@ -148,7 +153,14 @@ class RandomModel(Model):
                     interior_point=self._get_last_point(),
                     bounds=self._convert_bounds(bounds),
                 )
-                points = polytope_sampler.draw(n).numpy()
+                num_generated = (
+                    len(self.generated_points)
+                    if self.generated_points is not None
+                    else 0
+                )
+                points = polytope_sampler.draw(
+                    n=n, seed=self.seed + num_generated
+                ).numpy()
             else:
                 raise e
 
