@@ -53,8 +53,10 @@ class KnowledgeGradientTest(TestCase):
         self.optimizer_options = {
             "num_restarts": 12,
             "raw_samples": 12,
-            "maxiter": 5,
-            "batch_limit": 1,
+            "options": {
+                "maxiter": 5,
+                "batch_limit": 1,
+            },
         }
         self.optimize_acqf = "ax.models.torch.botorch_kg.optimize_acqf"
         self.X_dummy = torch.ones(1, 3, **self.tkwargs)
@@ -110,8 +112,10 @@ class KnowledgeGradientTest(TestCase):
         optimizer_options2 = {
             "num_restarts": 1,
             "raw_samples": 1,
-            "maxiter": 5,
-            "batch_limit": 1,
+            "options": {
+                "maxiter": 5,
+                "batch_limit": 1,
+            },
             "partial_restarts": 2,
         }
         torch_opt_config.model_gen_options["optimizer_kwargs"] = optimizer_options2
@@ -131,7 +135,15 @@ class KnowledgeGradientTest(TestCase):
         dummy_acq = PosteriorMean(model=model.model, posterior_transform=posterior_tf)
         with mock.patch(
             "ax.models.torch.utils.PosteriorMean", return_value=dummy_acq
-        ) as mock_posterior_mean:
+        ) as mock_posterior_mean, mock.patch(
+            "ax.models.torch.utils.get_botorch_objective_and_transform",
+            return_value=(
+                None,
+                ScalarizedPosteriorTransform(
+                    weights=torch.tensor([1.0], dtype=torch.double)
+                ),
+            ),
+        ):
             gen_results = model.gen(
                 n=n,
                 search_space_digest=self.search_space_digest,
