@@ -5,7 +5,7 @@
 # LICENSE file in the root directory of this source tree.
 
 import dataclasses
-from typing import Any, Callable, Dict, List, Optional, Tuple
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 import torch
 from ax.core.search_space import SearchSpaceDigest
@@ -122,6 +122,7 @@ class KnowledgeGradient(BotorchModel):
             outcome_constraints = torch_opt_config.outcome_constraints
 
         objective, posterior_transform = get_botorch_objective_and_transform(
+            botorch_acqf_class=qKnowledgeGradient,
             model=model,
             objective_weights=objective_weights,
             outcome_constraints=outcome_constraints,
@@ -376,6 +377,13 @@ def _optimize_and_get_candidates(
 
     botorch_rounding_func = get_rounding_func(rounding_func)
 
+    opt_options: Dict[str, Union[bool, float, int, str]] = {
+        "batch_limit": 8,
+        "maxiter": 200,
+        "method": "L-BFGS-B",
+        "nonnegative": False,
+    }
+    opt_options.update(optimizer_options.get("options", {}))
     candidates, _ = optimize_acqf(
         acq_function=acq_function,
         bounds=bounds_,
@@ -385,12 +393,7 @@ def _optimize_and_get_candidates(
         post_processing_func=botorch_rounding_func,
         num_restarts=num_restarts,
         raw_samples=raw_samples,
-        options={
-            "batch_limit": optimizer_options.get("batch_limit", 8),
-            "maxiter": optimizer_options.get("maxiter", 200),
-            "method": "L-BFGS-B",
-            "nonnegative": optimizer_options.get("nonnegative", False),
-        },
+        options=opt_options,
         batch_initial_conditions=batch_initial_conditions,
     )
     new_x = candidates.detach().cpu()
