@@ -34,6 +34,8 @@ from logging import Logger
 from typing import Any, Callable, Dict, List, Optional, Tuple
 
 import numpy as np
+
+import pyro
 import torch
 from ax.exceptions.core import AxError
 from ax.models.torch.botorch import (
@@ -66,11 +68,12 @@ from ax.utils.common.docutils import copy_doc
 from ax.utils.common.logger import get_logger
 from ax.utils.common.typeutils import checked_cast
 from botorch.acquisition import AcquisitionFunction
-from botorch.models.fully_bayesian import _psd_safe_pyro_mvn_sample
 from botorch.models.gpytorch import GPyTorchModel
 from botorch.models.model import Model
 from botorch.models.model_list_gp_regression import ModelListGP
 from botorch.posteriors.gpytorch import GPyTorchPosterior
+
+from gpytorch.kernels.kernel import dist
 from torch import Tensor
 
 logger: Logger = get_logger(__name__)
@@ -115,42 +118,11 @@ def predict_from_model_mcmc(model: Model, X: Tensor) -> Tuple[Tensor, Tensor]:
 
 
 def compute_dists(X: Tensor, Z: Tensor, lengthscale: Tensor) -> Tensor:
-    """Compute kernel distances.
-
-    TODO: use gpytorch `Distance` module. This will require some care to make sure
-    jit compilation works as expected.
-    """
+    """Compute kernel distances."""
     mean = X.mean(dim=0)
-    X_ = (X - mean).div(lengthscale)
-    Z_ = (Z - mean).div(lengthscale)
-    x1 = X_
-    x2 = Z_
-    adjustment = x1.mean(-2, keepdim=True)
-    x1 = x1 - adjustment
-    # x1 and x2 should be identical in all dims except -2 at this point
-    x2 = x2 - adjustment
-    x1_eq_x2 = torch.equal(x1, x2)
-
-    # Compute squared distance matrix using quadratic expansion
-    x1_norm = x1.pow(2).sum(dim=-1, keepdim=True)
-    x1_pad = torch.ones_like(x1_norm)
-    if x1_eq_x2 and not x1.requires_grad and not x2.requires_grad:
-        x2_norm, x2_pad = x1_norm, x1_pad
-    else:
-        x2_norm = x2.pow(2).sum(dim=-1, keepdim=True)
-        x2_pad = torch.ones_like(x2_norm)
-    x2_norm = x2.pow(2).sum(dim=-1, keepdim=True)
-    x2_pad = torch.ones_like(x2_norm)
-    x1_ = torch.cat([-2.0 * x1, x1_norm, x1_pad], dim=-1)
-    x2_ = torch.cat([x2, x2_pad, x2_norm], dim=-1)
-    res = x1_.matmul(x2_.transpose(-2, -1))
-
-    if x1_eq_x2 and not x1.requires_grad and not x2.requires_grad:
-        res.diagonal(dim1=-2, dim2=-1).fill_(0)
-
-    # Zero out negative values
-    dist = res.clamp_min_(1e-30).sqrt()
-    return dist
+    x1 = (X - mean).div(lengthscale)
+    x2 = (Z - mean).div(lengthscale)
+    return dist(x1=x1, x2=x2, x1_eq_x2=torch.equal(x1, x2))
 
 
 def matern_kernel(X: Tensor, Z: Tensor, lengthscale: Tensor, nu: float = 2.5) -> Tensor:
@@ -225,19 +197,22 @@ def single_task_pyro_model(
         X_tf = X
     # compute kernel
     if gp_kernel == "matern":
-        k = matern_kernel(X=X_tf, Z=X_tf, lengthscale=lengthscale)
+        K = matern_kernel(X=X_tf, Z=X_tf, lengthscale=lengthscale)
     elif gp_kernel == "rbf":
-        k = rbf_kernel(X=X_tf, Z=X_tf, lengthscale=lengthscale)
+        K = rbf_kernel(X=X_tf, Z=X_tf, lengthscale=lengthscale)
     else:
         raise ValueError(f"Expected kernel to be 'rbf' or 'matern', got {gp_kernel}")
 
     # add noise
-    k = outputscale * k + noise * torch.eye(X.shape[0], dtype=X.dtype, device=X.device)
+    K = outputscale * K + noise * torch.eye(X.shape[0], dtype=X.dtype, device=X.device)
 
-    _psd_safe_pyro_mvn_sample(
-        name="Y",
-        loc=mean.view(-1).expand(X.shape[0]),
-        covariance_matrix=k,
+    pyro.sample(
+        "Y",
+        # pyre-fixme[16]: Module `distributions` has no attribute `MultivariateNormal`.
+        pyro.distributions.MultivariateNormal(
+            loc=mean.view(-1).expand(X.shape[0]),
+            covariance_matrix=K,
+        ),
         obs=Y,
     )
 
@@ -392,10 +367,7 @@ def run_inference(
 ) -> Dict[str, Tensor]:
     start = time.time()
     try:
-        # @manual=fbsource//third-party/pypi/pyro-ppl:pyro-ppl
         from pyro.infer.mcmc import MCMC, NUTS
-
-        # @manual=fbsource//third-party/pypi/pyro-ppl:pyro-ppl
         from pyro.infer.mcmc.util import print_summary
     except ImportError:  # pragma: no cover
         raise RuntimeError("Cannot call run_inference without pyro installed!")
