@@ -9,20 +9,21 @@ import warnings
 from contextlib import ExitStack
 from typing import Dict
 from unittest import mock
+from unittest.mock import Mock
 
 import numpy as np
 import torch
 from ax.core.search_space import SearchSpaceDigest
 from ax.exceptions.core import AxWarning, UnsupportedError
 from ax.models.torch.botorch_modular.acquisition import Acquisition
-from ax.models.torch.botorch_modular.list_surrogate import ListSurrogate
-from ax.models.torch.botorch_modular.model import BoTorchModel
+from ax.models.torch.botorch_modular.model import BoTorchModel, SurrogateSpec
 from ax.models.torch.botorch_modular.surrogate import Surrogate
 from ax.models.torch.botorch_modular.utils import choose_model_class
 from ax.models.torch.utils import _filter_X_observed
 from ax.models.torch_base import TorchOptConfig
 from ax.utils.common.constants import Keys
 from ax.utils.common.testutils import TestCase
+from ax.utils.common.typeutils import checked_cast
 from ax.utils.testing.mock import fast_botorch_optimize
 from ax.utils.testing.torch_stubs import get_torch_test_data
 from botorch.acquisition.input_constructors import (
@@ -36,9 +37,10 @@ from botorch.acquisition.multi_objective.monte_carlo import (
 from botorch.acquisition.multi_objective.objective import WeightedMCMultiOutputObjective
 from botorch.models.gp_regression import FixedNoiseGP, SingleTaskGP
 from botorch.models.gp_regression_fidelity import FixedNoiseMultiFidelityGP
-from botorch.models.model_list_gp_regression import ModelListGP
+from botorch.models.model import ModelList
 from botorch.sampling.normal import SobolQMCNormalSampler
 from botorch.utils.datasets import FixedNoiseDataset, SupervisedDataset
+from gpytorch.mlls.exact_marginal_log_likelihood import ExactMarginalLogLikelihood
 
 
 CURRENT_PATH: str = __name__
@@ -46,10 +48,9 @@ MODEL_PATH: str = BoTorchModel.__module__
 SURROGATE_PATH: str = Surrogate.__module__
 UTILS_PATH: str = choose_model_class.__module__
 ACQUISITION_PATH: str = Acquisition.__module__
-LIST_SURROGATE_PATH: str = ListSurrogate.__module__
 NEHVI_PATH: str = qNoisyExpectedHypervolumeImprovement.__module__
 
-ACQ_OPTIONS: Dict[Keys, SobolQMCNormalSampler] = {
+ACQ_OPTIONS: Dict[str, SobolQMCNormalSampler] = {
     Keys.SAMPLER: SobolQMCNormalSampler(sample_shape=torch.Size([1024]))
 }
 
@@ -65,8 +66,6 @@ class BoTorchModelTest(TestCase):
             surrogate=self.surrogate,
             acquisition_class=self.acquisition_class,
             botorch_acqf_class=self.botorch_acqf_class,
-            # pyre-fixme[6]: For 4th param expected `Optional[Dict[str,
-            #  typing.Any]]` but got `Dict[Keys, SobolQMCNormalSampler]`.
             acquisition_options=self.acquisition_options,
         )
 
@@ -162,11 +161,43 @@ class BoTorchModelTest(TestCase):
         self.assertTrue(mdl2.refit_on_cv)
         self.assertFalse(mdl2.warm_start_refit)
 
-    def test_surrogate_property(self) -> None:
-        self.assertEqual(self.surrogate, self.model.surrogate)
-        self.model._surrogate = None
-        with self.assertRaisesRegex(ValueError, "Surrogate has not yet been set."):
-            self.model.surrogate
+    def test_surrogates_property(self) -> None:
+        self.assertEqual(self.surrogate, list(self.model.surrogates.values())[0])
+
+    def test_Xs_property(self) -> None:
+        self.model.fit(
+            datasets=self.block_design_training_data,
+            metric_names=self.metric_names,
+            search_space_digest=self.mf_search_space_digest,
+            candidate_metadata=self.candidate_metadata,
+        )
+
+        self.assertEqual(len(self.model.Xs), 1)
+        self.assertTrue(
+            self.model.Xs[0].equal(torch.tensor([[1.0, 2.0, 3.0], [2.0, 3.0, 4.0]]))
+        )
+
+        with self.assertRaisesRegex(NotImplementedError, "Xs not implemented"):
+            self.model._surrogates = {"foo": Surrogate(), "bar": Surrogate()}
+            self.model.Xs
+
+    def test_dtype(self) -> None:
+        self.model.fit(
+            datasets=self.block_design_training_data,
+            metric_names=self.metric_names,
+            search_space_digest=self.mf_search_space_digest,
+            candidate_metadata=self.candidate_metadata,
+        )
+        self.assertEqual(self.model.dtype, torch.float32)
+
+    def test_device(self) -> None:
+        self.model.fit(
+            datasets=self.block_design_training_data,
+            metric_names=self.metric_names,
+            search_space_digest=self.mf_search_space_digest,
+            candidate_metadata=self.candidate_metadata,
+        )
+        self.assertEqual(self.model.device, torch.device("cpu"))
 
     def test_botorch_acqf_class_property(self) -> None:
         self.assertEqual(self.botorch_acqf_class, self.model.botorch_acqf_class)
@@ -176,44 +207,9 @@ class BoTorchModelTest(TestCase):
         ):
             self.model.botorch_acqf_class
 
-    @mock.patch(f"{SURROGATE_PATH}.Surrogate.fit")
-    @mock.patch(f"{MODEL_PATH}.choose_model_class", return_value=SingleTaskGP)
-    # pyre-fixme[3]: Return type must be annotated.
-    # pyre-fixme[2]: Parameter must be annotated.
-    def test_fit(self, mock_choose_model_class, mock_fit):
-        # If surrogate is not yet set, initialize it with dispatcher functions.
-        self.model._surrogate = None
-        self.model.fit(
-            datasets=self.block_design_training_data,
-            metric_names=self.metric_names,
-            search_space_digest=self.mf_search_space_digest,
-            candidate_metadata=self.candidate_metadata,
-        )
-        # `choose_model_class` is called.
-        mock_choose_model_class.assert_called_with(
-            datasets=self.block_design_training_data,
-            search_space_digest=self.mf_search_space_digest,
-        )
-        # Since we want to refit on updates but not warm start refit, we clear the
-        # state dict.
-        mock_fit.assert_called_with(
-            datasets=self.block_design_training_data,
-            metric_names=self.metric_names,
-            search_space_digest=self.mf_search_space_digest,
-            candidate_metadata=self.candidate_metadata,
-            state_dict=None,
-            refit=True,
-            original_metric_names=self.metric_names,
-        )
-        # ensure that error is raised when len(metric_names) != len(datasets)
-        with self.assertRaisesRegex(
-            ValueError, "Length of datasets and metric_names must match"
-        ):
-            self.model.fit(
-                datasets=self.block_design_training_data,
-                metric_names=self.metric_names * 2,
-                search_space_digest=self.mf_search_space_digest,
-            )
+    @mock.patch(f"{SURROGATE_PATH}.choose_model_class", return_value=SingleTaskGP)
+    @mock.patch(f"{SURROGATE_PATH}.use_model_list", return_value=False)
+    def test_construct(self, _: Mock, mock_choose_model_class: Mock) -> None:
         # Ensure proper error is raised when mixing data w/ and w/o variance
         ds1, ds2 = self.non_block_design_training_data
         with self.assertRaisesRegex(
@@ -224,6 +220,7 @@ class BoTorchModelTest(TestCase):
                 metric_names=self.metric_names * 2,
                 search_space_digest=self.mf_search_space_digest,
             )
+
         # Ensure non-block design data is converted with warnings
         ds = self.block_design_training_data[0]
         X1 = ds.X()
@@ -244,10 +241,53 @@ class BoTorchModelTest(TestCase):
             )
         )
 
+        # Test autoset
+        self.model._surrogates = {}
+        self.model.fit(
+            datasets=self.block_design_training_data,
+            metric_names=self.metric_names,
+            search_space_digest=self.mf_search_space_digest,
+            candidate_metadata=self.candidate_metadata,
+        )
+        # `choose_model_class` is called.
+        mock_choose_model_class.assert_called_with(
+            datasets=self.block_design_training_data,
+            search_space_digest=self.mf_search_space_digest,
+        )
+
+    @mock.patch(f"{SURROGATE_PATH}.Surrogate.fit")
+    def test_fit(self, mock_fit: Mock) -> None:
+        # If surrogate is not yet set, initialize it with dispatcher functions.
+        self.model._surrogates = {}
+        self.model.fit(
+            datasets=self.block_design_training_data,
+            metric_names=self.metric_names,
+            search_space_digest=self.mf_search_space_digest,
+            candidate_metadata=self.candidate_metadata,
+        )
+
+        # Since we want to refit on updates but not warm start refit, we clear the
+        # state dict.
+        mock_fit.assert_called_with(
+            datasets=self.block_design_training_data,
+            metric_names=self.metric_names,
+            search_space_digest=self.mf_search_space_digest,
+            candidate_metadata=self.candidate_metadata,
+            state_dict=None,
+            refit=True,
+        )
+        # ensure that error is raised when len(metric_names) != len(datasets)
+        with self.assertRaisesRegex(
+            ValueError, "Length of datasets and metric_names must match"
+        ):
+            self.model.fit(
+                datasets=self.block_design_training_data,
+                metric_names=self.metric_names * 2,
+                search_space_digest=self.mf_search_space_digest,
+            )
+
     @mock.patch(f"{SURROGATE_PATH}.Surrogate.update")
-    # pyre-fixme[3]: Return type must be annotated.
-    # pyre-fixme[2]: Parameter must be annotated.
-    def test_update(self, mock_update):
+    def test_update(self, mock_update: Mock) -> None:
         # test assertion that model needs to be fit first
         empty_model = BoTorchModel()
         with self.assertRaisesRegex(
@@ -260,7 +300,7 @@ class BoTorchModelTest(TestCase):
                 candidate_metadata=self.candidate_metadata,
             )
         # test assertion that datasets cannot be None
-        empty_model._surrogate = mock.Mock()  # mock the Surrogate
+        empty_model._surrogates = {"key": mock.Mock()}  # mock the Surrogates
         with self.assertRaisesRegex(
             UnsupportedError, "BoTorchModel.update requires data for all outcomes."
         ):
@@ -293,7 +333,7 @@ class BoTorchModelTest(TestCase):
             expected_state_dict = (
                 None
                 if refit_on_update and not warm_start_refit
-                else self.model.surrogate.model.state_dict()
+                else self.model.surrogates[Keys.ONLY_SURROGATE].model.state_dict()
             )
 
             # Check for correct call args
@@ -312,27 +352,53 @@ class BoTorchModelTest(TestCase):
                 mock_update.call_args_list[-1][1].get("refit"), refit_on_update
             )
             if expected_state_dict is None:
-                self.assertIsNone(
-                    mock_update.call_args_list[-1][1].get("state_dict"),
-                    expected_state_dict,
-                )
+                self.assertIsNone(mock_update.call_args_list[-1][1].get("state_dict"))
             else:
                 self.assertEqual(
                     mock_update.call_args_list[-1][1].get("state_dict").keys(),
                     expected_state_dict.keys(),
                 )
 
+        # Test with autoset surrogate.
+        autoset_model = BoTorchModel(
+            acquisition_class=self.acquisition_class,
+            botorch_acqf_class=self.botorch_acqf_class,
+            acquisition_options=self.acquisition_options,
+        )
+        autoset_model.fit(
+            datasets=self.block_design_training_data,
+            metric_names=self.metric_names,
+            search_space_digest=self.mf_search_space_digest,
+            candidate_metadata=self.candidate_metadata,
+        )
+        autoset_model.refit_on_update = True
+        autoset_model.warm_start_refit = False
+        autoset_model.update(
+            datasets=self.block_design_training_data,
+            metric_names=self.metric_names,
+            search_space_digest=self.mf_search_space_digest,
+            candidate_metadata=self.candidate_metadata,
+        )
+        # Check for correct call args
+        call_args = mock_update.call_args_list[-1][1]
+        self.assertEqual(call_args.get("datasets"), self.block_design_training_data)
+        self.assertEqual(call_args.get("metric_names"), self.metric_names)
+        self.assertEqual(
+            call_args.get("search_space_digest"), self.mf_search_space_digest
+        )
+        self.assertEqual(call_args.get("candidate_metadata"), self.candidate_metadata)
+
+        # Check correct `refit` and `state_dict` values.
+        self.assertEqual(mock_update.call_args_list[-1][1].get("refit"), True)
+        self.assertIsNone(mock_update.call_args_list[-1][1].get("state_dict"))
+
     @mock.patch(f"{SURROGATE_PATH}.Surrogate.predict")
-    # pyre-fixme[3]: Return type must be annotated.
-    # pyre-fixme[2]: Parameter must be annotated.
-    def test_predict(self, mock_predict):
+    def test_predict(self, mock_predict: Mock) -> None:
         self.model.predict(X=self.X_test)
         mock_predict.assert_called_with(X=self.X_test)
 
     @mock.patch(f"{MODEL_PATH}.BoTorchModel.fit")
-    # pyre-fixme[3]: Return type must be annotated.
-    # pyre-fixme[2]: Parameter must be annotated.
-    def test_cross_validate(self, mock_fit):
+    def test_cross_validate(self, mock_fit: Mock) -> None:
         self.model.fit(
             datasets=self.block_design_training_data,
             metric_names=self.metric_names,
@@ -340,7 +406,7 @@ class BoTorchModelTest(TestCase):
             candidate_metadata=self.candidate_metadata,
         )
 
-        old_surrogate = self.model.surrogate
+        old_surrogate = self.model.surrogates[Keys.ONLY_SURROGATE]
         old_surrogate._model = mock.MagicMock()
         old_surrogate._model.state_dict.return_value = {"key": "val"}
 
@@ -376,12 +442,12 @@ class BoTorchModelTest(TestCase):
 
             # Check that surrogate is reset back to `old_surrogate` at the
             # end of cross-validation.
-            self.assertTrue(self.model.surrogate is old_surrogate)
+            self.assertTrue(self.model.surrogates[Keys.ONLY_SURROGATE] is old_surrogate)
 
             expected_state_dict = (
                 None
                 if refit_on_cv and not warm_start_refit
-                else self.model.surrogate.model.state_dict()
+                else self.model.surrogates[Keys.ONLY_SURROGATE].model.state_dict()
             )
 
             # Check correct `refit` and `state_dict` values.
@@ -393,7 +459,10 @@ class BoTorchModelTest(TestCase):
                 )
             else:
                 self.assertEqual(
-                    mock_fit.call_args_list[-1][1].get("state_dict").keys(),
+                    mock_fit.call_args_list[-1][1]
+                    .get("state_dicts")
+                    .get(Keys.ONLY_SURROGATE)
+                    .keys(),
                     expected_state_dict.keys(),
                 )
 
@@ -410,20 +479,14 @@ class BoTorchModelTest(TestCase):
     @mock.patch(
         f"{MODEL_PATH}.choose_botorch_acqf_class", return_value=qExpectedImprovement
     )
-    # pyre-fixme[3]: Return type must be annotated.
     def test_gen(
         self,
-        # pyre-fixme[2]: Parameter must be annotated.
-        mock_choose_botorch_acqf_class,
-        # pyre-fixme[2]: Parameter must be annotated.
-        mock_inequality_constraints,
-        # pyre-fixme[2]: Parameter must be annotated.
-        mock_rounding,
-        # pyre-fixme[2]: Parameter must be annotated.
-        mock_acquisition,
-        # pyre-fixme[2]: Parameter must be annotated.
-        mock_construct_options,
-    ):
+        mock_choose_botorch_acqf_class: Mock,
+        mock_inequality_constraints: Mock,
+        mock_rounding: Mock,
+        mock_acquisition: Mock,
+        mock_construct_options: Mock,
+    ) -> None:
         mock_acquisition.return_value.optimize.return_value = (
             torch.tensor([1.0]),
             torch.tensor([2.0]),
@@ -433,8 +496,9 @@ class BoTorchModelTest(TestCase):
             acquisition_class=Acquisition,
             acquisition_options=self.acquisition_options,
         )
-        model.surrogate.construct(
+        model.surrogates[Keys.ONLY_SURROGATE].construct(
             datasets=self.block_design_training_data,
+            metric_names=["metric"],
             fidelity_features=self.mf_search_space_digest.fidelity_features,
         )
         model._botorch_acqf_class = None
@@ -463,7 +527,7 @@ class BoTorchModelTest(TestCase):
         self.assertEqual(model._botorch_acqf_class, qExpectedImprovement)
         # Assert `acquisition_class` called with kwargs
         mock_acquisition.assert_called_with(
-            surrogate=self.surrogate,
+            surrogates={Keys.ONLY_SURROGATE: self.surrogate},
             botorch_acqf_class=model.botorch_acqf_class,
             search_space_digest=self.mf_search_space_digest,
             torch_opt_config=self.torch_opt_config,
@@ -481,7 +545,7 @@ class BoTorchModelTest(TestCase):
 
     @fast_botorch_optimize
     def test_best_point(self) -> None:
-        self.model._surrogate = None
+        self.model._surrogates = {}
         self.model.fit(
             datasets=self.block_design_training_data,
             metric_names=self.metric_names,
@@ -514,16 +578,17 @@ class BoTorchModelTest(TestCase):
         return_value=({"num_fantasies": 64}, {"num_restarts": 40, "raw_samples": 1024}),
     )
     @mock.patch(f"{CURRENT_PATH}.Acquisition", autospec=True)
-    # pyre-fixme[3]: Return type must be annotated.
-    # pyre-fixme[2]: Parameter must be annotated.
-    def test_evaluate_acquisition_function(self, mock_ei, _mock_construct_options):
+    def test_evaluate_acquisition_function(
+        self, mock_ei: Mock, _mock_construct_options: Mock
+    ) -> None:
         model = BoTorchModel(
             surrogate=self.surrogate,
             acquisition_class=Acquisition,
             acquisition_options=self.acquisition_options,
         )
-        model.surrogate.construct(
+        model.surrogates[Keys.ONLY_SURROGATE].construct(
             datasets=self.block_design_training_data,
+            metric_names=["metric"],
             search_space_digest=SearchSpaceDigest(
                 feature_names=[],
                 bounds=[],
@@ -540,12 +605,18 @@ class BoTorchModelTest(TestCase):
         # instance of that class, we use `mock_ei.return_value.evaluate`
         mock_ei.return_value.evaluate.assert_called()
 
-    @mock.patch(f"{LIST_SURROGATE_PATH}.ListSurrogate.__init__", return_value=None)
-    @mock.patch(f"{LIST_SURROGATE_PATH}.ListSurrogate.fit", return_value=None)
-    # pyre-fixme[3]: Return type must be annotated.
-    # pyre-fixme[2]: Parameter must be annotated.
-    def test_surrogate_options_propagation(self, _, mock_init):
-        model = BoTorchModel(surrogate_options={"some_option": "some_value"})
+    @mock.patch(f"{MODEL_PATH}.Surrogate.__init__", return_value=None)
+    @mock.patch(f"{SURROGATE_PATH}.Surrogate.fit", return_value=None)
+    def test_surrogate_model_options_propagation(
+        self, _: Mock, mock_init: Mock
+    ) -> None:
+        model = BoTorchModel(
+            surrogate_specs={
+                "name": SurrogateSpec(
+                    botorch_model_kwargs={"some_option": "some_value"}
+                )
+            }
+        )
         model.fit(
             datasets=self.non_block_design_training_data,
             metric_names=self.metric_names_for_list_surrogate,
@@ -553,11 +624,43 @@ class BoTorchModelTest(TestCase):
             candidate_metadata=self.candidate_metadata,
         )
         mock_init.assert_called_with(
-            botorch_submodel_class_per_outcome={
-                outcome: FixedNoiseMultiFidelityGP
-                for outcome in self.metric_names_for_list_surrogate
-            },
-            some_option="some_value",
+            botorch_model_class=None,
+            model_options={"some_option": "some_value"},
+            mll_class=ExactMarginalLogLikelihood,
+            mll_options={},
+            covar_module_class=None,
+            covar_module_options=None,
+            likelihood_class=None,
+            likelihood_options=None,
+            input_transform=None,
+            outcome_transform=None,
+            allow_batched_models=True,
+        )
+
+    @mock.patch(f"{MODEL_PATH}.Surrogate.__init__", return_value=None)
+    @mock.patch(f"{SURROGATE_PATH}.Surrogate.fit", return_value=None)
+    def test_surrogate_options_propagation(self, _: Mock, mock_init: Mock) -> None:
+        model = BoTorchModel(
+            surrogate_specs={"name": SurrogateSpec(allow_batched_models=False)}
+        )
+        model.fit(
+            datasets=self.non_block_design_training_data,
+            metric_names=self.metric_names_for_list_surrogate,
+            search_space_digest=self.mf_search_space_digest,
+            candidate_metadata=self.candidate_metadata,
+        )
+        mock_init.assert_called_with(
+            botorch_model_class=None,
+            model_options={},
+            mll_class=ExactMarginalLogLikelihood,
+            mll_options={},
+            covar_module_class=None,
+            covar_module_options=None,
+            likelihood_class=None,
+            likelihood_options=None,
+            input_transform=None,
+            outcome_transform=None,
+            allow_batched_models=False,
         )
 
     @mock.patch(
@@ -565,8 +668,7 @@ class BoTorchModelTest(TestCase):
         # Dummy candidates and acquisition function value.
         return_value=(torch.tensor([[2.0]]), torch.tensor([1.0])),
     )
-    # pyre-fixme[3]: Return type must be annotated.
-    def test_list_surrogate_choice(self, _):  # , mock_extract_training_data):
+    def test_model_list_choice(self, _) -> None:  # , mock_extract_training_data):
         model = BoTorchModel()
         model.fit(
             datasets=self.non_block_design_training_data,
@@ -574,11 +676,11 @@ class BoTorchModelTest(TestCase):
             search_space_digest=self.mf_search_space_digest,
             candidate_metadata=self.candidate_metadata,
         )
-        # A list surrogate should be chosen, since Xs are not all the same.
-        self.assertIsInstance(model.surrogate, ListSurrogate)
-        self.assertIsInstance(model.surrogate.model, ModelListGP)
-        # pyre-fixme[29]: `Union[BoundMethod[typing.Callable(torch._tensor.Tensor.__i...
-        for submodel in model.surrogate.model.models:
+        # A model list should be chosen, since Xs are not all the same.
+        model_list = checked_cast(
+            ModelList, model.surrogates[Keys.AUTOSET_SURROGATE].model
+        )
+        for submodel in model_list.models:
             # There are fidelity features and nonempty Yvars, so
             # fixed noise MFGP should be chosen.
             self.assertIsInstance(submodel, FixedNoiseMultiFidelityGP)
@@ -588,8 +690,7 @@ class BoTorchModelTest(TestCase):
         # Dummy candidates and acquisition function value.
         return_value=(torch.tensor([[2.0]]), torch.tensor([1.0])),
     )
-    # pyre-fixme[3]: Return type must be annotated.
-    def test_MOO(self, _):
+    def test_MOO(self, _) -> None:
         # Add mock for qNEHVI input constructor to catch arguments passed to it.
         qNEHVI_input_constructor = get_acqf_input_constructor(
             qNoisyExpectedHypervolumeImprovement
@@ -609,7 +710,9 @@ class BoTorchModelTest(TestCase):
             search_space_digest=self.search_space_digest,
             candidate_metadata=self.candidate_metadata,
         )
-        self.assertIsInstance(model.surrogate.model, FixedNoiseGP)
+        self.assertIsInstance(
+            model.surrogates[Keys.AUTOSET_SURROGATE].model, FixedNoiseGP
+        )
         gen_results = model.gen(
             n=1,
             search_space_digest=self.mf_search_space_digest,
