@@ -13,6 +13,7 @@ from ax.core.search_space import SearchSpaceDigest
 from ax.exceptions.core import AxWarning, UnsupportedError
 from ax.models.torch.botorch_modular.utils import (
     _get_shared_rows,
+    _tensor_difference,
     choose_botorch_acqf_class,
     choose_model_class,
     construct_acquisition_and_optimizer_options,
@@ -28,6 +29,7 @@ from botorch.acquisition.monte_carlo import qNoisyExpectedImprovement
 from botorch.acquisition.multi_objective.monte_carlo import (
     qNoisyExpectedHypervolumeImprovement,
 )
+from botorch.models.fully_bayesian import SaasFullyBayesianSingleTaskGP
 from botorch.models.gp_regression import FixedNoiseGP, SingleTaskGP
 from botorch.models.gp_regression_fidelity import (
     FixedNoiseMultiFidelityGP,
@@ -253,6 +255,21 @@ class BoTorchModelUtilsTest(TestCase):
                 botorch_model_class=SingleTaskGP,
             )
         )
+        # Multi-output with allow_batched_models
+        self.assertFalse(
+            use_model_list(
+                datasets=2 * [SupervisedDataset(X=self.Xs[0], Y=Y) for Y in self.Ys],
+                botorch_model_class=SingleTaskGP,
+                allow_batched_models=True,
+            )
+        )
+        self.assertTrue(
+            use_model_list(
+                datasets=2 * [SupervisedDataset(X=self.Xs[0], Y=Y) for Y in self.Ys],
+                botorch_model_class=SingleTaskGP,
+                allow_batched_models=False,
+            )
+        )
         self.assertTrue(
             use_model_list(
                 datasets=[
@@ -267,6 +284,42 @@ class BoTorchModelUtilsTest(TestCase):
                 datasets=self.supervised_datasets, botorch_model_class=MultiTaskGP
             )
         )
+        # Not using model list with single outcome.
+        self.assertFalse(
+            use_model_list(
+                datasets=self.supervised_datasets,
+                botorch_model_class=SaasFullyBayesianSingleTaskGP,
+            )
+        )
+        # Using it with multiple outcomes.
+        self.assertTrue(
+            use_model_list(
+                datasets=[
+                    SupervisedDataset(X=self.Xs[0], Y=self.Ys[0]),
+                    SupervisedDataset(X=self.Xs2[0], Y=self.Ys2[0]),
+                ],
+                botorch_model_class=SaasFullyBayesianSingleTaskGP,
+            )
+        )
+        self.assertTrue(
+            use_model_list(
+                datasets=[
+                    SupervisedDataset(X=self.Xs[0], Y=self.Ys[0].repeat(1, 2)),
+                ],
+                botorch_model_class=SaasFullyBayesianSingleTaskGP,
+            )
+        )
+
+    def test_tensor_difference(self) -> None:
+        n, m = 3, 2
+        A = torch.arange(n * m).reshape(n, m)
+        B = torch.cat((A[: n - 1], torch.randn(2, m)), dim=0)
+        # permute B
+        B = B[torch.randperm(len(B))]
+
+        C = _tensor_difference(A=A, B=B)
+
+        self.assertEqual(C.size(dim=0), 2)
 
 
 class ConvertToBlockDesignTest(TestCase):
