@@ -37,6 +37,8 @@ from ax.modelbridge.torch import TorchModelBridge
 from ax.modelbridge.transforms.choice_encode import OrderedChoiceEncode
 from ax.modelbridge.transforms.derelativize import Derelativize
 from ax.modelbridge.transforms.int_to_float import IntToFloat
+from ax.modelbridge.transforms.one_hot import OneHot
+from ax.modelbridge.transforms.remove_fixed import RemoveFixed
 from ax.modelbridge.transforms.search_space_to_choice import SearchSpaceToChoice
 from ax.models.torch.posterior_mean import get_PosteriorMean
 from ax.models.torch_base import TorchModel
@@ -123,13 +125,14 @@ def get_observed_pareto_frontiers(
     data: Optional[Data] = None,
     rel: bool = True,
     arm_names: Optional[List[str]] = None,
+    is_pex: Optional[bool] = False,
 ) -> List[ParetoFrontierResults]:
     """
     Find all Pareto points from an experiment.
 
     Uses only values as observed in the data; no modeling is involved. Makes no
     assumption about the search space or types of parameters. If "data" is provided will
-    use that, otherwise will use all data attached to the experiment.
+    use that, otherwise will use all data already attached to the experiment.
 
     Uses all arms present in data; does not filter according to experiment
     search space. If arm_names is specified, will filter to just those arm whose names
@@ -143,7 +146,7 @@ def get_observed_pareto_frontiers(
 
     Args:
         experiment: The experiment.
-        data: Data to use for computing Pareto frontier. If not provided, will fetch
+        data: Data to use for computing Pareto frontier. If not provided, will lookup
             data from experiment.
         rel: Relativize, if status quo on experiment.
         arm_names: If provided, computes Pareto frontier only from among the provided
@@ -152,7 +155,7 @@ def get_observed_pareto_frontiers(
     Returns: ParetoFrontierResults that can be used with interact_pareto_frontier.
     """
     if data is None:
-        data = experiment.fetch_data()
+        data = experiment.lookup_data()
     if experiment.optimization_config is None:
         raise ValueError("Experiment must have an optimization config")
     if arm_names is not None:
@@ -163,7 +166,10 @@ def get_observed_pareto_frontiers(
             # Make sure status quo is always included, for derelativization
             arm_names.append(experiment.status_quo.name)
         data = Data(data.df[data.df["arm_name"].isin(arm_names)])
-    mb = get_tensor_converter_model(experiment=experiment, data=data)
+    if is_pex:
+        mb = pex_get_tensor_converter_model(experiment=experiment, data=data)
+    else:
+        mb = get_tensor_converter_model(experiment=experiment, data=data)
     pareto_observations = observed_pareto_frontier(modelbridge=mb)
     # Convert to ParetoFrontierResults
     objective_metric_names = {
@@ -262,6 +268,35 @@ def to_nonrobust_search_space(search_space: SearchSpace) -> SearchSpace:
         return search_space
 
 
+# TODO: delete this function after merging with get_tensor_converter_model
+def pex_get_tensor_converter_model(
+    experiment: Experiment, data: Data
+) -> TorchModelBridge:
+    """
+    Copy of get_tensor_converter_model which retains the old transforms for pex usage
+
+    Args:
+        experiment: Experiment.
+        data: Data for fitting the model.
+
+    Returns: A torch modelbridge with transforms set.
+    """
+    # Transforms is the minimal set that will work for converting any search
+    # space to tensors.
+    return TorchModelBridge(
+        experiment=experiment,
+        search_space=to_nonrobust_search_space(experiment.search_space),
+        data=data,
+        model=TorchModel(),
+        transforms=[Derelativize, SearchSpaceToChoice, OrderedChoiceEncode, IntToFloat],
+        transform_configs={
+            "Derelativize": {"use_raw_status_quo": True},
+            "SearchSpaceToChoice": {"use_ordered": True},
+        },
+        fit_out_of_design=True,
+    )
+
+
 def get_tensor_converter_model(experiment: Experiment, data: Data) -> TorchModelBridge:
     """
     Constructs a minimal model for converting things to tensors.
@@ -285,11 +320,7 @@ def get_tensor_converter_model(experiment: Experiment, data: Data) -> TorchModel
         search_space=to_nonrobust_search_space(experiment.search_space),
         data=data,
         model=TorchModel(),
-        transforms=[Derelativize, SearchSpaceToChoice, OrderedChoiceEncode, IntToFloat],
-        transform_configs={
-            "Derelativize": {"use_raw_status_quo": True},
-            "SearchSpaceToChoice": {"use_ordered": True},
-        },
+        transforms=[RemoveFixed, OrderedChoiceEncode, OneHot, IntToFloat],
         fit_out_of_design=True,
     )
 
