@@ -170,6 +170,10 @@ class Scheduler(WithDBSettingsBase, BestPointMixin):
     # Number of trials that existed on the scheduler's experiment before
     # the scheduler instantiation with that experiment.
     _num_preexisting_trials: int
+    # Total number of MetricFetchEs encountered during the course of optimization. Note
+    # this is different from and may be greater than the number of trials that have
+    # been marked either FAILED or ABANDONED due to metric fetching errors.
+    _num_metric_fetch_e_encountered: int = 0
     # Number of trials that have been marked either FAILED or ABANDONED due to
     # MetricFetchE being encountered during _fetch_and_process_trials_data_results
     _num_trials_bad_due_to_err: int = 0
@@ -437,6 +441,7 @@ class Scheduler(WithDBSettingsBase, BestPointMixin):
         return self._get_best_trial(
             experiment=self.experiment,
             generation_strategy=self.generation_strategy,
+            optimization_config=optimization_config,
             trial_indices=trial_indices,
             use_model_predictions=use_model_predictions,
         )
@@ -451,6 +456,7 @@ class Scheduler(WithDBSettingsBase, BestPointMixin):
         return self._get_pareto_optimal_parameters(
             experiment=self.experiment,
             generation_strategy=self.generation_strategy,
+            optimization_config=optimization_config,
             trial_indices=trial_indices,
             use_model_predictions=use_model_predictions,
         )
@@ -470,6 +476,30 @@ class Scheduler(WithDBSettingsBase, BestPointMixin):
             use_model_predictions=use_model_predictions,
         )
 
+    @copy_doc(BestPointMixin.get_trace)
+    def get_trace(
+        self,
+        optimization_config: Optional[MultiObjectiveOptimizationConfig] = None,
+    ) -> List[float]:
+        return BestPointMixin._get_trace(
+            experiment=self.experiment,
+            optimization_config=optimization_config,
+        )
+
+    @copy_doc(BestPointMixin.get_trace_by_progression)
+    def get_trace_by_progression(
+        self,
+        optimization_config: Optional[OptimizationConfig] = None,
+        bins: Optional[List[float]] = None,
+        final_progression_only: bool = False,
+    ) -> Tuple[List[float], List[float]]:
+        return BestPointMixin._get_trace_by_progression(
+            experiment=self.experiment,
+            optimization_config=optimization_config,
+            bins=bins,
+            final_progression_only=final_progression_only,
+        )
+
     def report_results(self, force_refit: bool = False) -> Dict[str, Any]:
         """Optional user-defined function for reporting intermediate
         and final optimization results (e.g. make some API call, write to some
@@ -1645,6 +1675,7 @@ class Scheduler(WithDBSettingsBase, BestPointMixin):
                 if result.is_ok():
                     continue
 
+                self._num_metric_fetch_e_encountered += 1
                 metric_fetch_e = result.unwrap_err()
 
                 self._report_metric_fetch_e(
