@@ -7,7 +7,7 @@
 import itertools
 from collections import namedtuple
 from logging import WARN
-from typing import List
+from typing import Dict, List
 from unittest.mock import patch
 
 import pandas as pd
@@ -22,12 +22,14 @@ from ax.service.utils.report_utils import (
     _get_metric_name_pairs,
     _get_objective_v_param_plots,
     _get_shortest_unique_suffix_dict,
+    compute_maximum_map_values,
     exp_to_df,
     Experiment,
     FEASIBLE_COL_NAME,
     get_standard_plots,
 )
 from ax.utils.common.testutils import TestCase
+from ax.utils.common.typeutils import checked_cast
 from ax.utils.testing.core_stubs import (
     get_branin_experiment,
     get_branin_experiment_with_multi_objective,
@@ -35,6 +37,7 @@ from ax.utils.testing.core_stubs import (
     get_experiment_with_observations,
     get_high_dimensional_branin_experiment,
     get_multi_type_experiment,
+    get_test_map_data_experiment,
 )
 from ax.utils.testing.mock import fast_botorch_optimize
 from ax.utils.testing.modeling_stubs import get_generation_strategy
@@ -54,6 +57,7 @@ DUMMY_SOURCE = "test_source"
 DUMMY_MAP_KEY = "test_map_key"
 TRUE_OBJECTIVE_NAME = "other_metric"
 TRUE_OBJECTIVE_MEAN = 2.3456
+DUMMY_MSG = "test_message"
 
 
 class ReportUtilsTest(TestCase):
@@ -69,7 +73,7 @@ class ReportUtilsTest(TestCase):
             ]
         ),
     )
-    def test_exp_to_df_ordering(self, _) -> None:
+    def test_exp_to_df_row_ordering(self, _) -> None:
         """
         This test verifies that the returned data frame indexes are
         in the same order as trial index. It mocks _merge_results_if_no_duplicates
@@ -82,6 +86,108 @@ class ReportUtilsTest(TestCase):
         for idx, row in df.iterrows():
             self.assertEqual(row["trial_index"], idx)
 
+    @patch(
+        "ax.service.utils.report_utils._merge_results_if_no_duplicates",
+        autospec=True,
+        return_value=pd.DataFrame(
+            [
+                # Trial indexes are out-of-order.
+                {
+                    "col1": 1,
+                    "arm_name": "a",
+                    "trial_status": "FAILED",
+                    "generation_method": "Manual",
+                    "trial_index": 1,
+                },
+                {
+                    "col1": 2,
+                    "arm_name": "b",
+                    "trial_status": "COMPLETED",
+                    "generation_method": "BO",
+                    "trial_index": 2,
+                },
+                {
+                    "col1": 3,
+                    "arm_name": "c",
+                    "trial_status": "COMPLETED",
+                    "generation_method": "Manual",
+                    "trial_index": 0,
+                },
+            ]
+        ),
+    )
+    def test_exp_to_df_col_ordering(self, _) -> None:
+        """
+        This test verifies that the returned data frame indexes are
+        in the same order as trial index. It mocks _merge_results_if_no_duplicates
+        to verify just the ordering of items in the final data frame.
+        """
+        exp = get_branin_experiment(with_trial=True)
+        df = exp_to_df(exp)
+        self.assertListEqual(
+            list(df.columns),
+            ["trial_index", "arm_name", "trial_status", "generation_method", "col1"],
+        )
+
+    def test_exp_to_df_max_map_value(self) -> None:
+        exp = get_test_map_data_experiment(num_trials=3, num_fetches=5, num_complete=0)
+
+        def compute_maximum_map_values_timestamp(
+            experiment: Experiment,
+        ) -> Dict[int, float]:
+            return compute_maximum_map_values(
+                experiment=experiment, map_key="timestamp"
+            )
+
+        df = exp_to_df(
+            exp=exp,
+            additional_fields_callables={  # pyre-ignore
+                "timestamp": compute_maximum_map_values_timestamp
+            },
+        )
+        self.assertEqual(df["timestamp"].tolist(), [5.0, 5.0, 5.0])
+
+    def test_exp_to_df_trial_timing(self) -> None:
+        # 1. test all have started, none have completed
+        exp = get_test_map_data_experiment(num_trials=3, num_fetches=5, num_complete=0)
+        df = exp_to_df(
+            exp=exp,
+            trial_attribute_fields=["time_run_started", "time_completed"],
+            always_include_field_columns=True,
+        )
+        self.assertTrue("time_run_started" in list(df.columns))
+        self.assertTrue("time_completed" in list(df.columns))
+        # since all trials started, all should have values
+        self.assertFalse(any(df["time_run_started"].isnull()))
+        # since no trials are complete, all should be None
+        self.assertTrue(all(df["time_completed"].isnull()))
+
+        # 2. test some trials not started yet
+        exp.trials[0]._time_run_started = None
+        df = exp_to_df(
+            exp=exp, trial_attribute_fields=["time_run_started", "time_completed"]
+        )
+        # the first trial should have NaN for rel_time_run_started
+        self.assertTrue(df["time_run_started"].isnull().iloc[0])
+
+        # 3. test all trials not started yet
+        for t in exp.trials.values():
+            t._time_run_started = None
+        df = exp_to_df(
+            exp=exp,
+            trial_attribute_fields=["time_run_started", "time_completed"],
+            always_include_field_columns=True,
+        )
+        self.assertTrue(all(df["time_run_started"].isnull()))
+
+        # 4. test some trials are completed
+        exp = get_test_map_data_experiment(num_trials=3, num_fetches=5, num_complete=2)
+        df = exp_to_df(
+            exp=exp, trial_attribute_fields=["time_run_started", "time_completed"]
+        )
+        # the last trial should have NaN for rel_time_completed
+        self.assertTrue(df["time_completed"].isnull().iloc[2])
+
     def test_exp_to_df(self) -> None:
         # MultiTypeExperiment should fail
         exp = get_multi_type_experiment()
@@ -163,12 +269,22 @@ class ReportUtilsTest(TestCase):
         self.assertEqual(
             df[df.arm_name == "custom"].iloc[0].generation_method, "Manual"
         )
-        # infeasible arm has `is_feasible = False`.
+        # failing feasibility calculation doesn't warns and suppresses error
         observations = [[1.0, 2.0, 3.0], [4.0, 5.0, -6.0], [7.0, 8.0, 9.0]]
         exp = get_experiment_with_observations(
             observations=observations,
             constrained=True,
         )
+        with patch(
+            f"{exp_to_df.__module__}._is_row_feasible", side_effect=KeyError(DUMMY_MSG)
+        ), self.assertLogs(logger="ax", level=WARN) as log:
+            exp_to_df(exp)
+            self.assertIn(
+                f"Feasibility calculation failed with error: '{DUMMY_MSG}'",
+                log.output[0],
+            )
+
+        # infeasible arm has `is_feasible = False`.
         df = exp_to_df(exp)
         self.assertListEqual(list(df[FEASIBLE_COL_NAME]), [True, False, True])
 
@@ -214,12 +330,15 @@ class ReportUtilsTest(TestCase):
         )
         self.assertEqual(len(plots), 6)
         self.assertTrue(all(isinstance(plot, go.Figure) for plot in plots))
+
+    @fast_botorch_optimize
+    def test_get_standard_plots_moo(self) -> None:
         exp = get_branin_experiment_with_multi_objective(with_batch=True)
         exp.optimization_config.objective.objectives[0].minimize = False
         exp.optimization_config.objective.objectives[1].minimize = True
-        # pyre-fixme[16]: Optional type has no attribute `_objective_thresholds`.
-        # pyre-fixme[16]: `OptimizationConfig` has no attribute `_objective_thresholds`.
-        exp.optimization_config._objective_thresholds = [
+        checked_cast(
+            MultiObjectiveOptimizationConfig, exp.optimization_config
+        )._objective_thresholds = [
             ObjectiveThreshold(
                 metric=exp.metrics["branin_a"], op=ComparisonOp.GEQ, bound=-100.0
             ),
@@ -239,20 +358,46 @@ class ReportUtilsTest(TestCase):
                 log.output[0],
             )
         self.assertEqual(len(plots), 6)
-        for ot in exp.optimization_config._objective_thresholds:
+
+    @fast_botorch_optimize
+    def test_get_standard_plots_moo_relative_constraints(self) -> None:
+        exp = get_branin_experiment_with_multi_objective(with_batch=True)
+        exp.optimization_config.objective.objectives[0].minimize = False
+        exp.optimization_config.objective.objectives[1].minimize = True
+        checked_cast(
+            MultiObjectiveOptimizationConfig, exp.optimization_config
+        )._objective_thresholds = [
+            ObjectiveThreshold(
+                metric=exp.metrics["branin_a"], op=ComparisonOp.GEQ, bound=-100.0
+            ),
+            ObjectiveThreshold(
+                metric=exp.metrics["branin_b"], op=ComparisonOp.LEQ, bound=100.0
+            ),
+        ]
+        exp.trials[0].run()
+
+        for ot in checked_cast(
+            MultiObjectiveOptimizationConfig, exp.optimization_config
+        )._objective_thresholds:
             ot.relative = False
         plots = get_standard_plots(
             experiment=exp, model=Models.MOO(experiment=exp, data=exp.fetch_data())
         )
-        self.assertEqual(len(plots), 7)
+        self.assertEqual(len(plots), 8)
 
-        # All plots are successfully created when objective thresholds are absent
-        exp.optimization_config._objective_thresholds = []
+    @fast_botorch_optimize
+    def test_get_standard_plots_moo_no_objective_thresholds(self) -> None:
+        exp = get_branin_experiment_with_multi_objective(with_batch=True)
+        exp.optimization_config.objective.objectives[0].minimize = False
+        exp.optimization_config.objective.objectives[1].minimize = True
+        exp.trials[0].run()
         plots = get_standard_plots(
             experiment=exp, model=Models.MOO(experiment=exp, data=exp.fetch_data())
         )
-        self.assertEqual(len(plots), 7)
+        self.assertEqual(len(plots), 8)
 
+    @fast_botorch_optimize
+    def test_get_standard_plots_map_data(self) -> None:
         exp = get_branin_experiment_with_timestamp_map_metric(with_status_quo=True)
         exp.new_trial().add_arm(exp.status_quo)
         exp.trials[0].run()
