@@ -5,6 +5,8 @@
 # LICENSE file in the root directory of this source tree.
 
 import re
+import warnings
+from pathlib import Path
 from typing import Any, Dict, Type
 
 from ax.benchmark.problems.hpo.torchvision import PyTorchCNNTorchvisionBenchmarkProblem
@@ -39,6 +41,9 @@ from ax.early_stopping.strategies import (
     PercentileEarlyStoppingStrategy,
     ThresholdEarlyStoppingStrategy,
 )
+from ax.exceptions.core import AxStorageWarning
+from ax.exceptions.storage import JSONEncodeError
+from ax.global_stopping.strategies.improvement import ImprovementGlobalStoppingStrategy
 from ax.modelbridge.completion_criterion import CompletionCriterion
 from ax.modelbridge.generation_strategy import GenerationStep, GenerationStrategy
 from ax.modelbridge.registry import _encode_callables_as_references
@@ -48,8 +53,12 @@ from ax.models.torch.botorch_modular.surrogate import Surrogate
 from ax.models.winsorization_config import WinsorizationConfig
 from ax.storage.botorch_modular_registry import CLASS_TO_REGISTRY
 from ax.storage.transform_registry import TRANSFORM_REGISTRY
+from ax.utils.common.constants import Keys
 from ax.utils.common.serialization import serialize_init_args
 from ax.utils.common.typeutils import not_none
+from ax.utils.common.typeutils_torch import torch_type_to_str
+from botorch.models.transforms.input import ChainedInputTransform, InputTransform
+from torch import Tensor
 
 
 def experiment_to_dict(experiment: Experiment) -> Dict[str, Any]:
@@ -459,11 +468,15 @@ def botorch_model_to_dict(model: BoTorchModel) -> Dict[str, Any]:
     """Convert Ax model to a dictionary."""
     return {
         "__type": model.__class__.__name__,
-        "surrogate": model.surrogate,
-        "surrogate_options": model.surrogate_options,
         "acquisition_class": model.acquisition_class,
-        "botorch_acqf_class": model._botorch_acqf_class,
         "acquisition_options": model.acquisition_options or {},
+        "surrogate": model._surrogates[Keys.ONLY_SURROGATE]
+        if Keys.ONLY_SURROGATE in model._surrogates
+        else None,
+        "surrogate_specs": model.surrogate_specs
+        if len(model.surrogate_specs) > 0
+        else None,
+        "botorch_acqf_class": model._botorch_acqf_class,
         "refit_on_update": model.refit_on_update,
         "refit_on_cv": model.refit_on_cv,
         "warm_start_refit": model.warm_start_refit,
@@ -477,6 +490,21 @@ def surrogate_to_dict(surrogate: Surrogate) -> Dict[str, Any]:
     return dict_representation
 
 
+def tensor_to_dict(obj: Tensor) -> Dict[str, Any]:
+    if obj.numel() > 1e4:
+        warnings.warn(
+            f"Attempting to serialize a tensor with {obj.numel()} elements. "
+            "This may result in storage issues.",
+            AxStorageWarning,
+        )
+    return {
+        "__type": "Tensor",
+        "value": obj.tolist(),
+        "dtype": {"__type": "torch_dtype", "value": torch_type_to_str(obj.dtype)},
+        "device": {"__type": "torch_device", "value": torch_type_to_str(obj.device)},
+    }
+
+
 # pyre-fixme[2]: Parameter annotation cannot contain `Any`.
 def botorch_modular_to_dict(class_type: Type[Any]) -> Dict[str, Any]:
     """Convert any class to a dictionary."""
@@ -501,11 +529,14 @@ def botorch_modular_to_dict(class_type: Type[Any]) -> Dict[str, Any]:
 
 
 # pyre-fixme[2]: Parameter annotation cannot contain `Any`.
-def botorch_component_to_dict(input_obj: Type[Any]) -> Dict[str, Any]:
+def botorch_component_to_dict(input_obj: Any) -> Dict[str, Any]:
     class_type = input_obj.__class__
-    state_dict = input_obj.state_dict()
-    # Cast dict values to float to avoid errors with Tensors.
-    state_dict = {k: float(v) for k, v in state_dict.items()}
+    if isinstance(input_obj, InputTransform):
+        # Input transforms cannot be initialized with their state dicts.
+        # We will instead extract the init args.
+        state_dict = botorch_input_transform_to_init_args(input_transform=input_obj)
+    else:
+        state_dict = dict(input_obj.state_dict())
     return {
         "__type": f"{class_type.__name__}",
         "index": class_type,
@@ -514,6 +545,22 @@ def botorch_component_to_dict(input_obj: Type[Any]) -> Dict[str, Any]:
     }
 
 
+def botorch_input_transform_to_init_args(
+    input_transform: InputTransform,
+) -> Dict[str, Any]:
+    """Extract the init kwargs from an input transform."""
+    if isinstance(input_transform, ChainedInputTransform):
+        return {k: botorch_component_to_dict(v) for k, v in input_transform.items()}
+    else:
+        try:
+            return input_transform.get_init_args()  # pyre-fixme [16]
+        except AttributeError:  # pragma: no cover
+            raise JSONEncodeError(
+                f"{input_transform.__class__.__name__} does not define `get_init_args` "
+                "method. Please implement it to enable storage."
+            )
+
+
 def percentile_early_stopping_strategy_to_dict(
     strategy: PercentileEarlyStoppingStrategy,
 ) -> Dict[str, Any]:
@@ -556,6 +603,19 @@ def logical_early_stopping_strategy_to_dict(
     }
 
 
+def improvement_global_stopping_strategy_to_dict(
+    gss: ImprovementGlobalStoppingStrategy,
+) -> Dict[str, Any]:
+    """Convert ImprovementGlobalStoppingStrategy to a dictionary."""
+    return {
+        "__type": gss.__class__.__name__,
+        "min_trials": gss.min_trials,
+        "window_size": gss.window_size,
+        "improvement_bar": gss.improvement_bar,
+        "inactive_when_pending_trials": gss.inactive_when_pending_trials,
+    }
+
+
 def winsorization_config_to_dict(config: WinsorizationConfig) -> Dict[str, Any]:
     """Convert Ax winsorization config to a dictionary."""
     return {
@@ -588,3 +648,7 @@ def risk_measure_to_dict(
         "risk_measure": risk_measure.risk_measure,
         "options": risk_measure.options,
     }
+
+
+def pathlib_to_dict(path: Path) -> Dict[str, Any]:
+    return {"__type": path.__class__.__name__, "pathsegments": [str(path)]}
