@@ -4,6 +4,7 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
+import pathlib
 from typing import Any, Callable, Dict, Type
 
 import torch
@@ -62,10 +63,12 @@ from ax.early_stopping.strategies.logical import (
     AndEarlyStoppingStrategy,
     OrEarlyStoppingStrategy,
 )
+from ax.global_stopping.strategies.improvement import ImprovementGlobalStoppingStrategy
 from ax.metrics.botorch_test_problem import BotorchTestProblemMetric
 from ax.metrics.branin import AugmentedBraninMetric, BraninMetric, NegativeBraninMetric
 from ax.metrics.branin_map import BraninTimestampMapMetric
 from ax.metrics.chemistry import ChemistryMetric, ChemistryProblemType
+from ax.metrics.dict_lookup import DictLookupMetric
 from ax.metrics.factorial import FactorialMetric
 from ax.metrics.hartmann6 import AugmentedHartmann6Metric, Hartmann6Metric
 from ax.metrics.jenatton import JenattonMetric
@@ -80,14 +83,17 @@ from ax.modelbridge.factory import Models
 from ax.modelbridge.generation_strategy import GenerationStep, GenerationStrategy
 from ax.modelbridge.transforms.base import Transform
 from ax.models.torch.botorch_modular.acquisition import Acquisition
-from ax.models.torch.botorch_modular.list_surrogate import ListSurrogate
-from ax.models.torch.botorch_modular.model import BoTorchModel
+from ax.models.torch.botorch_modular.model import BoTorchModel, SurrogateSpec
 from ax.models.torch.botorch_modular.surrogate import Surrogate
 from ax.models.winsorization_config import WinsorizationConfig
 from ax.runners.botorch_test_problem import BotorchTestProblemRunner
 from ax.runners.synthetic import SyntheticRunner
 from ax.service.utils.scheduler_options import SchedulerOptions, TrialType
-from ax.storage.json_store.decoders import class_from_json, transform_type_from_json
+from ax.storage.json_store.decoders import (
+    class_from_json,
+    pathlib_from_json,
+    transform_type_from_json,
+)
 from ax.storage.json_store.encoders import (
     arm_to_dict,
     batch_to_dict,
@@ -102,6 +108,7 @@ from ax.storage.json_store.encoders import (
     generation_step_to_dict,
     generation_strategy_to_dict,
     generator_run_to_dict,
+    improvement_global_stopping_strategy_to_dict,
     logical_early_stopping_strategy_to_dict,
     map_data_to_dict,
     map_key_info_to_dict,
@@ -116,6 +123,7 @@ from ax.storage.json_store.encoders import (
     outcome_constraint_to_dict,
     parameter_constraint_to_dict,
     parameter_distribution_to_dict,
+    pathlib_to_dict,
     percentile_early_stopping_strategy_to_dict,
     pytorch_cnn_torchvision_benchmark_problem_to_dict,
     range_parameter_to_dict,
@@ -134,6 +142,7 @@ from ax.storage.json_store.encoders import (
 from ax.storage.utils import DomainType, ParameterConstraintType
 from botorch.acquisition.acquisition import AcquisitionFunction
 from botorch.models.model import Model
+from botorch.models.transforms.input import ChainedInputTransform, Normalize, Round
 from gpytorch.constraints import Interval
 from gpytorch.likelihoods.likelihood import Likelihood
 from gpytorch.mlls.marginal_log_likelihood import MarginalLogLikelihood
@@ -154,8 +163,10 @@ CORE_ENCODER_REGISTRY: Dict[Type, Callable[[Any], Dict[str, Any]]] = {
     BotorchTestProblemRunner: runner_to_dict,
     BraninMetric: metric_to_dict,
     BraninTimestampMapMetric: metric_to_dict,
+    ChainedInputTransform: botorch_component_to_dict,
     ChoiceParameter: choice_parameter_to_dict,
     Data: data_to_dict,
+    DictLookupMetric: metric_to_dict,
     Experiment: experiment_to_dict,
     FactorialMetric: metric_to_dict,
     FixedParameter: fixed_parameter_to_dict,
@@ -164,9 +175,9 @@ CORE_ENCODER_REGISTRY: Dict[Type, Callable[[Any], Dict[str, Any]]] = {
     GenerationStrategy: generation_strategy_to_dict,
     GeneratorRun: generator_run_to_dict,
     Hartmann6Metric: metric_to_dict,
+    ImprovementGlobalStoppingStrategy: improvement_global_stopping_strategy_to_dict,
     Interval: botorch_component_to_dict,
     JenattonMetric: metric_to_dict,
-    ListSurrogate: surrogate_to_dict,
     L2NormMetric: metric_to_dict,
     MapData: map_data_to_dict,
     MapKeyInfo: map_key_info_to_dict,
@@ -177,6 +188,7 @@ CORE_ENCODER_REGISTRY: Dict[Type, Callable[[Any], Dict[str, Any]]] = {
     MultiObjective: multi_objective_to_dict,
     MultiObjectiveOptimizationConfig: multi_objective_optimization_config_to_dict,
     MultiTypeExperiment: multi_type_experiment_to_dict,
+    Normalize: botorch_component_to_dict,
     PercentileEarlyStoppingStrategy: percentile_early_stopping_strategy_to_dict,
     SklearnMetric: metric_to_dict,
     ChemistryMetric: metric_to_dict,
@@ -190,12 +202,19 @@ CORE_ENCODER_REGISTRY: Dict[Type, Callable[[Any], Dict[str, Any]]] = {
     OutcomeConstraint: outcome_constraint_to_dict,
     ParameterConstraint: parameter_constraint_to_dict,
     ParameterDistribution: parameter_distribution_to_dict,
+    pathlib.Path: pathlib_to_dict,
+    pathlib.PurePath: pathlib_to_dict,
+    pathlib.PosixPath: pathlib_to_dict,
+    pathlib.WindowsPath: pathlib_to_dict,
+    pathlib.PurePosixPath: pathlib_to_dict,
+    pathlib.PureWindowsPath: pathlib_to_dict,
     PyTorchCNNTorchvisionBenchmarkProblem: pytorch_cnn_torchvision_benchmark_problem_to_dict,  # noqa
     PyTorchCNNMetric: metric_to_dict,
     PyTorchCNNTorchvisionRunner: runner_to_dict,
     RangeParameter: range_parameter_to_dict,
     RiskMeasure: risk_measure_to_dict,
     RobustSearchSpace: robust_search_space_to_dict,
+    Round: botorch_component_to_dict,
     ScalarizedObjective: scalarized_objective_to_dict,
     SearchSpace: search_space_to_dict,
     HierarchicalSearchSpace: search_space_to_dict,
@@ -227,8 +246,9 @@ CORE_CLASS_ENCODER_REGISTRY: Dict[Type, Callable[[Any], Dict[str, Any]]] = {
     Transform: transform_type_to_dict,  # Ax general (not just MBM) component
 }
 
-# pyre-fixme[24]: Generic type `type` expects 1 type parameter, use `typing.Type` to
-#  avoid runtime subscripting errors.
+# TODO Clean up type signature. Decoders should be allowed to be any method from some
+# splattable inputs to the resultant class, not just Types with kwarg inits.
+# pyre-fixme[9, 24]
 CORE_DECODER_REGISTRY: Dict[str, Type] = {
     "AbandonedArm": AbandonedArm,
     "AndEarlyStoppingStrategy": AndEarlyStoppingStrategy,
@@ -245,12 +265,14 @@ CORE_DECODER_REGISTRY: Dict[str, Type] = {
     "BotorchTestProblemRunner": BotorchTestProblemRunner,
     "BraninMetric": BraninMetric,
     "BraninTimestampMapMetric": BraninTimestampMapMetric,
+    "ChainedInputTransform": ChainedInputTransform,
     "ChemistryMetric": ChemistryMetric,
     "ChemistryProblemType": ChemistryProblemType,
     "ChoiceParameter": ChoiceParameter,
     "ComparisonOp": ComparisonOp,
     "Data": Data,
     "DataType": DataType,
+    "DictLookupMetric": DictLookupMetric,
     "DomainType": DomainType,
     "Experiment": Experiment,
     "FactorialMetric": FactorialMetric,
@@ -262,9 +284,10 @@ CORE_DECODER_REGISTRY: Dict[str, Type] = {
     "GeneratorRunStruct": GeneratorRunStruct,
     "Hartmann6Metric": Hartmann6Metric,
     "HierarchicalSearchSpace": HierarchicalSearchSpace,
+    "ImprovementGlobalStoppingStrategy": ImprovementGlobalStoppingStrategy,
     "Interval": Interval,
     "JenattonMetric": JenattonMetric,
-    "ListSurrogate": ListSurrogate,
+    "ListSurrogate": Surrogate,  # For backwards compatibility
     "L2NormMetric": L2NormMetric,
     "MapData": MapData,
     "MapMetric": MapMetric,
@@ -279,6 +302,7 @@ CORE_DECODER_REGISTRY: Dict[str, Type] = {
     "MultiTypeExperiment": MultiTypeExperiment,
     "NegativeBraninMetric": NegativeBraninMetric,
     "NoisyFunctionMetric": NoisyFunctionMetric,
+    "Normalize": Normalize,
     "Objective": Objective,
     "ObjectiveThreshold": ObjectiveThreshold,
     "OptimizationConfig": OptimizationConfig,
@@ -289,6 +313,12 @@ CORE_DECODER_REGISTRY: Dict[str, Type] = {
     "ParameterConstraintType": ParameterConstraintType,
     "ParameterDistribution": ParameterDistribution,
     "ParameterType": ParameterType,
+    "Path": pathlib_from_json,
+    "PurePath": pathlib_from_json,
+    "PosixPath": pathlib_from_json,
+    "WindowsPath": pathlib_from_json,
+    "PurePosixPath": pathlib_from_json,
+    "PureWindowsPath": pathlib_from_json,
     "PercentileEarlyStoppingStrategy": PercentileEarlyStoppingStrategy,
     "PyTorchCNNTorchvisionBenchmarkProblem": PyTorchCNNTorchvisionBenchmarkProblem,
     "PyTorchCNNMetric": PyTorchCNNMetric,
@@ -296,6 +326,7 @@ CORE_DECODER_REGISTRY: Dict[str, Type] = {
     "RangeParameter": RangeParameter,
     "RiskMeasure": RiskMeasure,
     "RobustSearchSpace": RobustSearchSpace,
+    "Round": Round,
     "ScalarizedObjective": ScalarizedObjective,
     "SchedulerOptions": SchedulerOptions,
     "SearchSpace": SearchSpace,
@@ -309,6 +340,7 @@ CORE_DECODER_REGISTRY: Dict[str, Type] = {
     # NOTE: SurrogateRunners -> SyntheticRunner on load due to complications
     "SurrogateRunner": SyntheticRunner,
     "SyntheticRunner": SyntheticRunner,
+    "SurrogateSpec": SurrogateSpec,
     "Trial": Trial,
     "TrialType": TrialType,
     "TrialStatus": TrialStatus,
