@@ -12,9 +12,9 @@ import numpy as np
 import torch
 from ax.core.metric import Metric
 from ax.core.runner import Runner
+from ax.exceptions.core import AxStorageWarning
 from ax.exceptions.storage import JSONDecodeError, JSONEncodeError
 from ax.metrics.jenatton import JenattonMetric
-from ax.modelbridge.base import ModelBridge
 from ax.modelbridge.registry import Models
 from ax.storage.json_store.decoder import (
     generation_strategy_from_json,
@@ -57,12 +57,15 @@ from ax.utils.testing.core_stubs import (
     get_batch_trial,
     get_botorch_model,
     get_botorch_model_with_default_acquisition_class,
+    get_botorch_model_with_surrogate_specs,
     get_branin_data,
     get_branin_experiment,
     get_branin_experiment_with_timestamp_map_metric,
     get_branin_metric,
+    get_chained_input_transform,
     get_choice_parameter,
     get_default_scheduler_options,
+    get_dict_lookup_metric,
     get_experiment_with_batch_and_single_trial,
     get_experiment_with_data,
     get_experiment_with_map_data,
@@ -74,8 +77,8 @@ from ax.utils.testing.core_stubs import (
     get_generator_run,
     get_hartmann_metric,
     get_hierarchical_search_space,
+    get_improvement_global_stopping_strategy,
     get_interval,
-    get_list_surrogate,
     get_map_data,
     get_map_key_info,
     get_metric,
@@ -92,6 +95,7 @@ from ax.utils.testing.core_stubs import (
     get_outcome_constraint,
     get_parameter_constraint,
     get_parameter_distribution,
+    get_pathlib_path,
     get_percentile_early_stopping_strategy,
     get_percentile_early_stopping_strategy_with_non_objective_metric_name,
     get_percentile_early_stopping_strategy_with_true_objective_metric_name,
@@ -114,6 +118,7 @@ from ax.utils.testing.modeling_stubs import (
     get_observation_features,
     get_transform_type,
 )
+from ax.utils.testing.utils import generic_equals
 
 
 # pyre-fixme[5]: Global expression must be annotated.
@@ -130,8 +135,11 @@ TEST_CASES = [
     ("BenchmarkResult", get_benchmark_result),
     ("BoTorchModel", get_botorch_model),
     ("BoTorchModel", get_botorch_model_with_default_acquisition_class),
+    ("BoTorchModel", get_botorch_model_with_surrogate_specs),
     ("BraninMetric", get_branin_metric),
+    ("ChainedInputTransform", get_chained_input_transform),
     ("ChoiceParameter", get_choice_parameter),
+    ("DictLookupMetric", get_dict_lookup_metric),
     ("Experiment", get_experiment_with_batch_and_single_trial),
     ("Experiment", get_experiment_with_trial_with_ttl),
     ("Experiment", get_experiment_with_data),
@@ -151,9 +159,9 @@ TEST_CASES = [
     ("GeneratorRun", get_generator_run),
     ("Hartmann6Metric", get_hartmann_metric),
     ("HierarchicalSearchSpace", get_hierarchical_search_space),
+    ("ImprovementGlobalStoppingStrategy", get_improvement_global_stopping_strategy),
     ("Interval", get_interval),
     ("JenattonMetric", JenattonMetric),
-    ("ListSurrogate", get_list_surrogate),
     ("MapData", get_map_data),
     ("MapData", get_map_data),
     ("MapKeyInfo", get_map_key_info),
@@ -169,6 +177,7 @@ TEST_CASES = [
     ("OrEarlyStoppingStrategy", get_or_early_stopping_strategy),
     ("OrderConstraint", get_order_constraint),
     ("OutcomeConstraint", get_outcome_constraint),
+    ("Path", get_pathlib_path),
     ("PercentileEarlyStoppingStrategy", get_percentile_early_stopping_strategy),
     (
         "PercentileEarlyStoppingStrategy",
@@ -267,7 +276,7 @@ class JSONStoreTest(TestCase):
             CORE_CLASS_ENCODER_REGISTRY,
         )
 
-    def testEncodeDecode(self) -> None:
+    def test_EncodeDecode(self) -> None:
         for class_, fake_func in TEST_CASES:
             # Can't load trials from JSON, because a batch needs an experiment
             # in order to be initialized
@@ -308,13 +317,21 @@ class JSONStoreTest(TestCase):
                 )
                 original_object = original_object.state_dict()
                 converted_object = converted_object.state_dict()
-            self.assertEqual(
-                original_object,
-                converted_object,
-                msg=f"Error encoding/decoding {class_}.",
-            )
+            try:
+                self.assertEqual(
+                    original_object,
+                    converted_object,
+                    msg=f"Error encoding/decoding {class_}.",
+                )
+            except RuntimeError as e:
+                if "Tensor with more than one value" in str(e):
+                    self.assertTrue(
+                        generic_equals(first=original_object, second=converted_object)
+                    )
+                else:
+                    raise e
 
-    def testEncodeDecodeTorchTensor(self) -> None:
+    def test_EncodeDecodeTorchTensor(self) -> None:
         x = torch.tensor(
             [[1.0, 2.0], [3.0, 4.0]], dtype=torch.float64, device=torch.device("cpu")
         )
@@ -337,6 +354,28 @@ class JSONStoreTest(TestCase):
         )
         self.assertTrue(torch.equal(x, x2))
 
+        # Warning on large tensor.
+        with self.assertWarnsRegex(AxStorageWarning, "serialize a tensor"):
+            object_to_json(
+                torch.ones(99_999),
+                encoder_registry=CORE_ENCODER_REGISTRY,
+                class_encoder_registry=CORE_CLASS_ENCODER_REGISTRY,
+            )
+
+        # Key error on desearialization.
+        x_json = object_to_json(
+            x,
+            encoder_registry=CORE_ENCODER_REGISTRY,
+            class_encoder_registry=CORE_CLASS_ENCODER_REGISTRY,
+        )
+        x_json.pop("dtype")
+        with self.assertRaisesRegex(JSONDecodeError, "construct a tensor"):
+            object_from_json(
+                x_json,
+                decoder_registry=CORE_DECODER_REGISTRY,
+                class_decoder_registry=CORE_CLASS_DECODER_REGISTRY,
+            )
+
     def testDecodeGenerationStrategy(self) -> None:
         generation_strategy = get_generation_strategy()
         experiment = get_branin_experiment()
@@ -373,11 +412,13 @@ class JSONStoreTest(TestCase):
             decoder_registry=CORE_DECODER_REGISTRY,
             class_decoder_registry=CORE_CLASS_DECODER_REGISTRY,
         )
+        # These fields of the reloaded GS are not expected to be set (both will be
+        # set during next model fitting call), so we unset them on the original GS as
+        # well.
+        generation_strategy._seen_trial_indices_by_status = None
+        generation_strategy._model = None
         self.assertEqual(generation_strategy, new_generation_strategy)
         self.assertIsInstance(new_generation_strategy._steps[0].model, Models)
-        # Since this GS has now generated one generator run, model should have
-        # been initialized and restored when decoding from JSON.
-        self.assertIsInstance(new_generation_strategy.model, ModelBridge)
 
         # Check that we can encode and decode the generation strategy after
         # it has generated some trials and been updated with some data.
@@ -395,9 +436,13 @@ class JSONStoreTest(TestCase):
             decoder_registry=CORE_DECODER_REGISTRY,
             class_decoder_registry=CORE_CLASS_DECODER_REGISTRY,
         )
+        # These fields of the reloaded GS are not expected to be set (both will be
+        # set during next model fitting call), so we unset them on the original GS as
+        # well.
+        generation_strategy._seen_trial_indices_by_status = None
+        generation_strategy._model = None
         self.assertEqual(generation_strategy, new_generation_strategy)
         self.assertIsInstance(new_generation_strategy._steps[0].model, Models)
-        self.assertIsInstance(new_generation_strategy.model, ModelBridge)
 
     def testEncodeDecodeNumpy(self) -> None:
         arr = np.array([[1, 2, 3], [4, 5, 6]])
@@ -525,17 +570,12 @@ class JSONStoreTest(TestCase):
 
     def testBadStateDict(self) -> None:
         interval = get_interval()
-        # pyre-fixme[6]: For 1st param expected `Type[typing.Any]` but got `Interval`.
         expected_json = botorch_component_to_dict(interval)
         with self.assertRaisesRegex(ValueError, "Received unused args"):
-            # pyre-fixme[6]: For 1st param expected `Type[typing.Any]` but got
-            #  `Interval`.
             expected_json = botorch_component_to_dict(interval)
             expected_json["state_dict"]["foo"] = "bar"
             botorch_component_from_json(interval.__class__, expected_json)
         with self.assertRaisesRegex(ValueError, "Missing required initialization args"):
-            # pyre-fixme[6]: For 1st param expected `Type[typing.Any]` but got
-            #  `Interval`.
             expected_json = botorch_component_to_dict(interval)
             del expected_json["state_dict"]["lower_bound"]
             botorch_component_from_json(interval.__class__, expected_json)
