@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -7,12 +7,13 @@
 from __future__ import annotations
 
 from contextlib import contextmanager, nullcontext
+from os import remove as remove_file
 from typing import Any, Callable, ContextManager, Generator, Optional, TypeVar
 
 from sqlalchemy import create_engine
 from sqlalchemy.engine.base import Engine
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.orm import Session, scoped_session, sessionmaker
+from sqlalchemy.orm import scoped_session, Session, sessionmaker
 
 
 # some constants for database fields
@@ -26,8 +27,8 @@ JSON_FIELD_LENGTH: int = 4096
 # Text(MEDIUMTEXT_BYTES) or Text(LONGTEXT_BYTES). This is preferable to
 # using MEDIUMTEXT and LONGTEXT directly because those are incompatible with
 # SQLite that is used in unit tests.
-MEDIUMTEXT_BYTES: int = 2 ** 24 - 1
-LONGTEXT_BYTES: int = 2 ** 32 - 1
+MEDIUMTEXT_BYTES: int = 2**24 - 1
+LONGTEXT_BYTES: int = 2**32 - 1
 
 # global database variables
 SESSION_FACTORY: Optional[Session] = None
@@ -50,7 +51,11 @@ Base = declarative_base(cls=SQABase)
 
 
 def create_mysql_engine_from_creator(
-    creator: Callable, echo: bool = False, pool_recycle: int = 10, **kwargs: Any
+    # pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
+    creator: Callable,
+    echo: bool = False,
+    pool_recycle: int = 10,
+    **kwargs: Any,
 ) -> Engine:
     """Create a SQLAlchemy engine with the MySQL dialect given a creator function.
 
@@ -104,6 +109,10 @@ def create_test_engine(path: Optional[str] = None, echo: bool = True) -> Engine:
 
     """
     if path is None:
+        # From SQLALchemy docs:
+        # "To use a SQLite :memory: database, specify an empty URL:
+        # `engine = create_engine('sqlite://')`"
+        # (https://docs.sqlalchemy.org/en/14/core/engines.html#sqlite)
         db_path = "sqlite://"
     else:
         db_path = "sqlite:///{path}".format(path=path)
@@ -112,6 +121,7 @@ def create_test_engine(path: Optional[str] = None, echo: bool = True) -> Engine:
 
 def init_engine_and_session_factory(
     url: Optional[str] = None,
+    # pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
     creator: Optional[Callable] = None,
     echo: bool = False,
     force_init: bool = False,
@@ -141,7 +151,6 @@ def init_engine_and_session_factory(
 
     if SESSION_FACTORY is not None:
         if force_init:
-            # pyre-fixme[16]: `Optional` has no attribute `bind`.
             SESSION_FACTORY.bind.dispose()
         else:
             return  # pragma: no cover
@@ -182,7 +191,6 @@ def init_test_engine_and_session_factory(
 
     if SESSION_FACTORY is not None:
         if force_init:
-            # pyre-fixme[16]: `Optional` has no attribute `bind`.
             SESSION_FACTORY.bind.dispose()
         else:
             return
@@ -194,6 +202,11 @@ def init_test_engine_and_session_factory(
     )
 
 
+def remove_test_db_file(tier_or_path: str) -> None:
+    """Remove the test DB file from system, useful for cleanup in tests."""
+    remove_file(tier_or_path)
+
+
 def create_all_tables(engine: Engine) -> None:
     """Create all tables that inherit from Base.
 
@@ -246,7 +259,6 @@ def get_engine() -> Engine:
     global SESSION_FACTORY
     if SESSION_FACTORY is None:
         raise ValueError("Engine must be initialized first.")  # pragma: no cover
-    # pyre-fixme[16]: `Optional` has no attribute `bind`.
     return SESSION_FACTORY.bind
 
 
