@@ -1,10 +1,12 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
 import os
+
+from logging import Logger
 from typing import Any, Callable, Dict, List, Optional, Sequence, Union
 
 from ax.core.base_trial import BaseTrial
@@ -13,14 +15,14 @@ from ax.core.generator_run import GeneratorRun
 from ax.core.runner import Runner
 from ax.exceptions.storage import SQADecodeError
 from ax.modelbridge.generation_strategy import GenerationStrategy
-from ax.storage.sqa_store.db import SQABase, session_scope
+from ax.storage.sqa_store.db import session_scope, SQABase
 from ax.storage.sqa_store.decoder import Decoder
 from ax.storage.sqa_store.encoder import Encoder
 from ax.storage.sqa_store.sqa_classes import (
-    SQATrial,
     SQAData,
     SQAGeneratorRun,
     SQARunner,
+    SQATrial,
 )
 from ax.storage.sqa_store.sqa_config import SQAConfig
 from ax.storage.sqa_store.utils import copy_db_ids
@@ -28,8 +30,7 @@ from ax.utils.common.base import Base
 from ax.utils.common.logger import get_logger
 from ax.utils.common.typeutils import checked_cast, not_none
 
-
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 
 def save_experiment(experiment: Experiment, config: Optional[SQAConfig] = None) -> None:
@@ -38,7 +39,6 @@ def save_experiment(experiment: Experiment, config: Optional[SQAConfig] = None)
         raise ValueError("Can only save instances of Experiment")
     if not experiment.has_name:
         raise ValueError("Experiment name must be set prior to saving.")
-
     config = config or SQAConfig()
     encoder = Encoder(config=config)
     decoder = Decoder(config=config)
@@ -151,11 +151,19 @@ def save_or_update_trial(
 
 
 def _save_or_update_trial(
-    experiment: Experiment, trial: BaseTrial, encoder: Encoder, decoder: Decoder
+    experiment: Experiment,
+    trial: BaseTrial,
+    encoder: Encoder,
+    decoder: Decoder,
+    reduce_state_generator_runs: bool = False,
 ) -> None:
     """Add new trial to the experiment, or update if already exists."""
     _save_or_update_trials(
-        experiment=experiment, trials=[trial], encoder=encoder, decoder=decoder
+        experiment=experiment,
+        trials=[trial],
+        encoder=encoder,
+        decoder=decoder,
+        reduce_state_generator_runs=reduce_state_generator_runs,
     )
 
 
@@ -164,6 +172,7 @@ def save_or_update_trials(
     trials: List[BaseTrial],
     config: Optional[SQAConfig] = None,
     batch_size: Optional[int] = None,
+    reduce_state_generator_runs: bool = False,
 ) -> None:
     """Add new trials to the experiment, or update if already exists
     (using default SQAConfig).
@@ -181,6 +190,7 @@ def save_or_update_trials(
         encoder=encoder,
         decoder=decoder,
         batch_size=batch_size,
+        reduce_state_generator_runs=reduce_state_generator_runs,
     )
 
 
@@ -190,6 +200,7 @@ def _save_or_update_trials(
     encoder: Encoder,
     decoder: Decoder,
     batch_size: Optional[int] = None,
+    reduce_state_generator_runs: bool = False,
 ) -> None:
     """Add new trials to the experiment, or update if they already exist.
 
@@ -201,17 +212,45 @@ def _save_or_update_trials(
     if experiment_id is None:
         raise ValueError("Must save experiment first.")
 
+    # pyre-fixme[53]: Captured variable `experiment_id` is not annotated.
+    # pyre-fixme[3]: Return type must be annotated.
     def add_experiment_id(sqa: Union[SQATrial, SQAData]):
         sqa.experiment_id = experiment_id
 
-    _bulk_merge_into_session(
-        objs=trials,
-        encode_func=encoder.trial_to_sqa,
-        decode_func=decoder.trial_from_sqa,
-        decode_args_list=[{"experiment": experiment} for _ in range(len(trials))],
-        modify_sqa=add_experiment_id,
-        batch_size=batch_size,
-    )
+    if reduce_state_generator_runs:
+        latest_trial = trials[-1]
+        trials_to_reduce_state = trials[0:-1]
+
+        # pyre-fixme[3]: Return type must be annotated.
+        def trial_to_reduced_state_sqa_encoder(t: BaseTrial):
+            return encoder.trial_to_sqa(t, generator_run_reduced_state=True)
+
+        _bulk_merge_into_session(
+            objs=trials_to_reduce_state,
+            encode_func=trial_to_reduced_state_sqa_encoder,
+            decode_func=decoder.trial_from_sqa,
+            decode_args_list=[{"experiment": experiment} for _ in range(len(trials))],
+            modify_sqa=add_experiment_id,
+            batch_size=batch_size,
+        )
+
+        _bulk_merge_into_session(
+            objs=[latest_trial],
+            encode_func=encoder.trial_to_sqa,
+            decode_func=decoder.trial_from_sqa,
+            decode_args_list=[{"experiment": experiment} for _ in range(len(trials))],
+            modify_sqa=add_experiment_id,
+            batch_size=batch_size,
+        )
+    else:
+        _bulk_merge_into_session(
+            objs=trials,
+            encode_func=encoder.trial_to_sqa,
+            decode_func=decoder.trial_from_sqa,
+            decode_args_list=[{"experiment": experiment} for _ in range(len(trials))],
+            modify_sqa=add_experiment_id,
+            batch_size=batch_size,
+        )
 
     datas = []
     data_encode_args = []
@@ -229,6 +268,10 @@ def _save_or_update_trials(
         encode_func=encoder.data_to_sqa,
         decode_func=decoder.data_from_sqa,
         encode_args_list=data_encode_args,
+        decode_args_list=[
+            {"data_constructor": experiment.default_data_constructor}
+            for _ in range(len(datas))
+        ],
         modify_sqa=add_experiment_id,
         batch_size=batch_size,
     )
@@ -239,6 +282,7 @@ def update_generation_strategy(
     generator_runs: List[GeneratorRun],
     config: Optional[SQAConfig] = None,
     batch_size: Optional[int] = None,
+    reduce_state_generator_runs: bool = False,
 ) -> None:
     """Update generation strategy's current step and attach generator runs
     (using default SQAConfig)."""
@@ -251,6 +295,7 @@ def update_generation_strategy(
         encoder=encoder,
         decoder=decoder,
         batch_size=batch_size,
+        reduce_state_generator_runs=reduce_state_generator_runs,
     )
 
 
@@ -260,6 +305,7 @@ def _update_generation_strategy(
     encoder: Encoder,
     decoder: Decoder,
     batch_size: Optional[int] = None,
+    reduce_state_generator_runs: bool = False,
 ) -> None:
     """Update generation strategy's current step and attach generator runs."""
     gs_sqa_class = encoder.config.class_to_sqa_class[GenerationStrategy]
@@ -283,12 +329,22 @@ def _update_generation_strategy(
             }
         )
 
+    # pyre-fixme[53]: Captured variable `gs_id` is not annotated.
+    # pyre-fixme[3]: Return type must be annotated.
     def add_generation_strategy_id(sqa: SQAGeneratorRun):
         sqa.generation_strategy_id = gs_id
 
+    # pyre-fixme[3]: Return type must be annotated.
+    def generator_run_to_sqa_encoder(gr: GeneratorRun, weight: Optional[float] = None):
+        return encoder.generator_run_to_sqa(
+            gr,
+            weight=weight,
+            reduced_state=reduce_state_generator_runs,
+        )
+
     _bulk_merge_into_session(
         objs=generator_runs,
-        encode_func=encoder.generator_run_to_sqa,
+        encode_func=generator_run_to_sqa_encoder,
         decode_func=decoder.generator_run_from_sqa,
         decode_args_list=[
             {
@@ -314,6 +370,8 @@ def update_runner_on_experiment(
     with session_scope() as session:
         session.query(runner_sqa_class).filter_by(experiment_id=exp_id).delete()
 
+    # pyre-fixme[53]: Captured variable `exp_id` is not annotated.
+    # pyre-fixme[3]: Return type must be annotated.
     def add_experiment_id(sqa: SQARunner):
         sqa.experiment_id = exp_id
 
@@ -346,10 +404,13 @@ def update_properties_on_experiment(
 
 def _merge_into_session(
     obj: Base,
+    # pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
     encode_func: Callable,
+    # pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
     decode_func: Callable,
     encode_args: Optional[Dict[str, Any]] = None,
     decode_args: Optional[Dict[str, Any]] = None,
+    # pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
     modify_sqa: Optional[Callable] = None,
 ) -> SQABase:
     """Given a user-facing object (that may or may not correspond to an
@@ -385,10 +446,13 @@ def _merge_into_session(
 
 def _bulk_merge_into_session(
     objs: Sequence[Base],
+    # pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
     encode_func: Callable,
+    # pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
     decode_func: Callable,
     encode_args_list: Optional[Union[List[None], List[Dict[str, Any]]]] = None,
     decode_args_list: Optional[Union[List[None], List[Dict[str, Any]]]] = None,
+    # pyre-fixme[24]: Generic type `Callable` expects 2 type parameters.
     modify_sqa: Optional[Callable] = None,
     batch_size: Optional[int] = None,
 ) -> List[SQABase]:
@@ -416,6 +480,8 @@ def _bulk_merge_into_session(
         sqas.append(sqa)
 
     # https://stackoverflow.com/a/312464
+    # pyre-fixme[3]: Return type must be annotated.
+    # pyre-fixme[2]: Parameter must be annotated.
     def split_into_batches(lst, n):
         for i in range(0, len(lst), n):
             yield lst[i : i + n]
@@ -440,6 +506,7 @@ def _bulk_merge_into_session(
     return new_sqas
 
 
+# pyre-fixme[2]: Parameter annotation cannot be `Any`.
 def _copy_db_ids_if_possible(new_obj: Any, obj: Any) -> None:
     """Wraps _copy_db_ids in a try/except, and logs warnings on error."""
     try:
