@@ -1,22 +1,21 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
+from logging import Logger
+
 from ax.plot.base import AxPlotConfig, AxPlotTypes
 from ax.plot.render import _js_requires, _wrap_js, plot_config_to_html
 from ax.utils.common.logger import get_logger
-
-# pyre-fixme[21]: Could not find module `IPython.display`.
 from IPython.display import display
 from plotly.offline import init_notebook_mode, iplot
 
-
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 
-def init_notebook_plotting(offline=False):
+def init_notebook_plotting(offline: bool = False) -> None:
     """Initialize plotting in notebooks, either in online or offline mode."""
     display_bundle = {"text/html": _wrap_js(_js_requires(offline=offline))}
     display(display_bundle, raw=True)
@@ -24,7 +23,7 @@ def init_notebook_plotting(offline=False):
     init_notebook_mode()
 
 
-def render(plot_config: AxPlotConfig, inject_helpers=False) -> None:
+def render(plot_config: AxPlotConfig, inject_helpers: bool = False) -> None:
     """Render plot config."""
     if plot_config.plot_type == AxPlotTypes.GENERIC:
         iplot(plot_config.data)
