@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -8,13 +8,14 @@ import logging
 import random
 import time
 from dataclasses import dataclass
+
+from logging import Logger
 from typing import Dict, List, Optional
 
 from ax.core.base_trial import TrialStatus
 from ax.utils.common.logger import get_logger
 
-
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 
 @dataclass
@@ -142,16 +143,22 @@ class BackendSimulator:
         if options is None:
             options = BackendSimulatorOptions()
 
+        # pyre-fixme[4]: Attribute must be annotated.
         self.max_concurrency = options.max_concurrency
+        # pyre-fixme[4]: Attribute must be annotated.
         self.time_scaling = options.time_scaling
+        # pyre-fixme[4]: Attribute must be annotated.
         self.failure_rate = options.failure_rate
+        # pyre-fixme[4]: Attribute must be annotated.
         self.use_update_as_start_time = options.use_update_as_start_time
         self._queued: List[SimTrial] = queued or []
         self._running: List[SimTrial] = running or []
         self._failed: List[SimTrial] = failed or []
         self._completed: List[SimTrial] = completed or []
+        # pyre-fixme[4]: Attribute must be annotated.
         self._internal_clock = options.internal_clock
         self._verbose_logging = verbose_logging
+        # pyre-fixme[4]: Attribute must be annotated.
         self._init_state = self.state()
         self._create_index_to_trial_map()
 
@@ -237,6 +244,7 @@ class BackendSimulator:
         )
 
     @classmethod
+    # pyre-fixme[3]: Return type must be annotated.
     def from_state(cls, state: BackendSimulatorState):
         """Construct a simulator from a state.
 
@@ -414,7 +422,7 @@ class BackendSimulator:
                 )
             elif (
                 trial.sim_completed_time is not None
-                and timestamp >= trial.sim_completed_time  # pyre-ignore[58]
+                and timestamp >= trial.sim_completed_time
             ):
                 completed_since_last.append(trial)  # was early stopped
             else:
